@@ -12,6 +12,12 @@
 # serve to show the default value.
 
 import sys, os
+try:
+    # When translating the docs to another language, this variable is set 
+    # elsewhere, so if it is not set, set it to a suitable default.
+    basedir
+except NameError:
+    basedir = os.path.dirname(os.path.abspath(__file__))
 
 # If your extensions are in another directory, add it here. If the directory
 # is relative to the documentation root, use os.path.abspath to make it
@@ -36,12 +42,13 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'tvtk'
-copyright = '2008-2015, Enthought Inc.'
+copyright = '2008-2016, Enthought Inc.'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 d = {}
-execfile(os.path.join('..', '..', '..', 'mayavi', '__init__.py'), d)
+fname = os.path.join(basedir, '..', '..', '..', 'mayavi', '__init__.py')
+exec(compile(open(fname).read(), fname, 'exec'), d)
 version = release = d['__version__']
 
 # There are two options for replacing |today|: either, you set today to some
@@ -81,7 +88,7 @@ pygments_style = 'sphinx'
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
 # given in html_static_path.
-html_style = 'default.css'
+html_theme = 'classic'
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
