@@ -1,8 +1,8 @@
 """
-An example showing a graph display between cities positionned on the
+An example showing a graph display between cities positioned on the
 Earth surface.
 
-This graph displays the longest fligh routes operated by Boing
+This graph displays the longest flight routes operated by Boing
 777. The two main interests of this example are that it shows how to
 build a graph of arbitrary connectivity, and that it shows how to
 position data on the surface of the Earth.
@@ -16,7 +16,7 @@ Another example of graph plotting, showing a different technique to plot
 the graph, can be seen on :ref:`example_delaunay_graph`.
 
 To simplify things we do not plot the connection on the surface of the
-Earth, but as straight lines going throught the Earth. As a result
+Earth, but as straight lines going through the Earth. As a result
 must use transparency to show the connection.
 
 Data source: http://www.777fleetpage.com/777fleetpage3.htm
@@ -71,8 +71,8 @@ routes_table = [i for i in csv.reader(routes_data.split('\n')[1:-1])]
 # Build a dictionnary returning GPS coordinates for each city
 cities_coord = dict()
 for line in list(csv.reader(cities_data.split('\n')))[1:-1]:
-    name, long, lat = line
-    cities_coord[name] = (float(long), float(lat))
+    name, long_, lat = line
+    cities_coord[name] = (float(long_), float(lat))
 
 # Store all the coordinates of connected cities in a list also keep
 # track of which city corresponds to a given index in the list. The
@@ -129,7 +129,7 @@ mlab.pipeline.surface(points, color=(1, 1, 1),
 
 ###############################################################################
 # Display city names
-for city, index in cities.iteritems():
+for city, index in cities.items():
     label = mlab.text(x[index], y[index], city, z=z[index],
                       width=0.016 * len(city), name=city)
     label.property.shadow = True
@@ -146,7 +146,7 @@ continents = mlab.pipeline.surface(continents_src, color=(0, 0, 0))
 ###############################################################################
 # Display a semi-transparent sphere, for the surface of the Earth
 
-# We use a sphere Glyph, throught the points3d mlab function, rather than
+# We use a sphere Glyph, through the points3d mlab function, rather than
 # building the mesh ourselves, because it gives a better transparent
 # rendering.
 sphere = mlab.points3d(0, 0, 0, scale_mode='none',
