@@ -17,12 +17,12 @@ achieving the same effect but the present form nicely illustrates item
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2004-2007, Enthought, Inc.
+# Copyright (c) 2004-2020, Enthought, Inc.
 # License: BSD Style.
 
 from tvtk.api import tvtk
 from tvtk.common import configure_input
-import numpy
+import numpy as np
 import time
 
 # First create a structured points data set.
@@ -31,16 +31,16 @@ sp = tvtk.StructuredPoints(origin=(-10., -10., 0.0),
                            spacing=(0.25, 0.25, 0.0))
 
 # Create some nice data at these points.
-x = numpy.arange(-10., 10., 0.25)
+x = np.arange(-10., 10., 0.25)
 y = x
-r = numpy.sqrt(x[:,None]**2+y**2)
+r = np.sqrt(x[:,None]**2+y**2)
 # We need the transpose so the data is as per VTK's expected format
 # where X coords vary fastest, Y next and then Z.
 try:
     import scipy.special
-    z = numpy.reshape(numpy.transpose(5.0*scipy.special.j0(r)), (-1,) )
+    z = np.reshape(np.transpose(5.0*scipy.special.j0(r)), (-1,) )
 except ImportError:
-    z = numpy.reshape(numpy.transpose(5.0*numpy.sin(r)/r), (-1,) )
+    z = np.reshape(np.transpose(5.0*np.sin(r)/r), (-1,) )
 
 # Now set the scalar data for the StructuredPoints object.  The
 # scalars of the structured points object will be a view into our
@@ -87,11 +87,10 @@ rwi.render()
 
 # The following is a crude approach but illustrates the point.
 scale = old_scale = 1.0
-pi = numpy.pi
-for i in numpy.arange(pi*0.5, 2.5*pi, 0.2):
+for i in np.arange(np.pi*0.5, 2.5*np.pi, 0.2):
     if abs(i) < 1.0e-10:
         continue
-    scale = numpy.sin(i)
+    scale = np.sin(i)
     # We change 'z' in-place
     z *= scale/old_scale
     # Reset the scalar range.
