@@ -1,11 +1,9 @@
 """MayaVi test related utilities.
 """
 # Author: Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
-# Copyright (c) 2005-2015, Enthought, Inc.
+# Copyright (c) 2005-2020, Enthought, Inc.
 # License: BSD Style.
 
-from __future__ import print_function
-
 # Standard library imports
 import gc
 import os
@@ -219,19 +217,19 @@ def _handle_failed_image(idiff, src_img, pngr, img_fname):
     jpegw.write()
 
     # write out the image that was generated.
-    pngw.set(file_name=f_base + ".test.png")
+    pngw.trait_set(file_name=f_base + ".test.png")
     configure_input(pngw, src_img)
     pngw.write()
 
     # write out a smaller version of the image that was generated.
     configure_input(shrink, idiff.input)
-    jpegw.set(file_name=f_base + ".test.small.jpg")
+    jpegw.trait_set(file_name=f_base + ".test.small.jpg")
     configure_input(jpegw, shrink)
     jpegw.write()
 
     # write out the valid image that matched.
     configure_input(shrink, idiff.image)
-    jpegw.set(file_name=f_base + ".small.jpg")
+    jpegw.trait_set(file_name=f_base + ".small.jpg")
     configure_input(jpegw, shrink)
     jpegw.write()
 
@@ -531,10 +529,7 @@ class TestCase(Mayavi):
         g.start_event_loop()
         if self.exception_info is not None:
             type, value, tb = self.exception_info
-            if sys.version_info[0] > 2:
-                raise type(value).with_traceback(tb)
-            else:
-                raise type(value)
+            raise type(value).with_traceback(tb)
 
     def run(self):
         """This starts everything up and runs the test.  Call main to
