@@ -5,10 +5,11 @@
     Part of the Mayavi project of the Enthought Tool Suite.
 """
 
-__version__ = '4.8.2'
+__version__ = '4.8.3'
 
 __requires__ = [
     'apptools',
+    'configobj',
     'envisage',
     'numpy',
     'pyface>=6.1.1',
@@ -16,7 +17,9 @@ __requires__ = [
     'traits>=6.0.0',
     'traitsui>=7.0.0',
     'packaging',
-    'vtk'
+    'importlib_resources; python_version<"3.11"',
+    'vtk',
+    'puremagic'
 ]
 
 __extras_require__ = {
