@@ -2,7 +2,7 @@
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005-2006, Enthought, Inc.
+# Copyright (c) 2005-2020, Enthought, Inc.
 # License: BSD Style.
 
 # Enthought library imports.
@@ -111,7 +111,7 @@ class CustomGridPlane(Component):
         """
         if len(self.inputs) == 0:
             return
-        input = self.inputs[0].outputs[0]
+        input = self.inputs[0].get_output_dataset()
         plane = None
         if input.is_a('vtkStructuredGrid'):
             plane = tvtk.StructuredGridGeometryFilter()
@@ -123,13 +123,13 @@ class CustomGridPlane(Component):
             msg = "The GridPlane component does not support the %s dataset."\
                   %(input.class_name)
             error(msg)
-            raise TypeError, msg
+            raise TypeError(msg)
 
         self.configure_connection(plane, self.inputs[0])
         self.plane = plane
         self._update_limits()
         self._update_voi()
-        self.outputs = [plane.output]
+        self.outputs = [plane]
 
     def update_data(self):
         """Override this method to do what is necessary when upstream
