@@ -3,19 +3,20 @@ to be used by various modules.
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005, Enthought, Inc.
+# Copyright (c) 2005-2020, Enthought, Inc.
 # License: BSD Style.
 
 # Enthought library imports.
-from traits.api import Event, Instance, List, Trait, Bool, TraitPrefixList
+from traits.api import Event, Instance, List, Trait, Bool
 from traitsui.api import View, Group, Item, InstanceEditor
 from tvtk.api import tvtk
-from tvtk.common import configure_input_data
+from tvtk.tvtk_base import PrefixList
 from apptools.persistence.state_pickler import set_state
 
 # Local imports.
 from mayavi.core.common import handle_children_state
 from mayavi.core.component import Component
+from mayavi.core.utils import DataSetHelper
 
 ######################################################################
 # `SourceWidget` class.
@@ -35,10 +36,10 @@ class SourceWidget(Component):
     # change and when the widget interaction is complete, 3)
     # 'non-interactive' -- poly_data is updated only explicitly at
     # users request by calling `object.update_poly_data`.
-    update_mode = Trait('interactive', TraitPrefixList(['interactive',
-                                                        'semi-interactive',
-                                                        'non-interactive']),
-                        desc='the speed at which the poly data is updated')
+    update_mode = PrefixList(
+        ['interactive', 'semi-interactive', 'non-interactive'],
+        default_value='interactive',
+        desc='the speed at which the poly data is updated')
 
     # A list of predefined glyph sources that can be used.
     widget_list = List(tvtk.Object, record=False)
@@ -52,6 +53,7 @@ class SourceWidget(Component):
     _first = Bool(True)
     _busy = Bool(False)
     _unpickling = Bool(False)
+    _bounds = List
 
     ########################################
     # View related traits.
@@ -85,7 +87,7 @@ class SourceWidget(Component):
         w = self.widget = self.widget_list[m.index(w_c_name)]
         # Set the input.
         if len(self.inputs) > 0:
-            self.configure_input_data(w, self.inputs[0].outputs[0])
+            self.configure_input(w, self.inputs[0].outputs[0])
         # Fix for the point widget.
         if w_c_name == 'PointWidget':
             w.place_widget()
@@ -96,6 +98,7 @@ class SourceWidget(Component):
         if w_c_name == 'PlaneWidget':
             w.origin = state.widget.origin
             w.normal = state.widget.normal
+            w.center = state.widget.center
             w.update_placement()
             w.get_poly_data(self.poly_data)
         elif w_c_name == 'SphereWidget':
@@ -157,13 +160,15 @@ class SourceWidget(Component):
         inp = self.inputs[0].outputs[0]
         w = self.widget
         self.configure_input(w, inp)
+        dsh = DataSetHelper(self.inputs[0].outputs[0])
+        b = dsh.get_bounds()
+        self._bounds = list(b)
         if self._first:
-            w.place_widget()
+            w.place_widget(b)
             self._first = False
 
         # If the dataset is effectively 2D switch to using the line
         # widget since that works best.
-        b = inp.bounds
         l = [(b[1]-b[0]), (b[3]-b[2]), (b[5]-b[4])]
         max_l = max(l)
         for i, x in enumerate(l):
@@ -219,8 +224,8 @@ class SourceWidget(Component):
             recorder.record('%s = %s'%(lhs, rhs))
 
         if len(self.inputs) > 0:
-            configure_input_data(value, self.inputs[0].outputs[0])
-            value.place_widget()
+            self.configure_input(value, self.inputs[0].outputs[0])
+            value.place_widget(self._bounds)
 
         value.on_trait_change(self.render)
         self.widgets = [value]
@@ -248,7 +253,7 @@ class SourceWidget(Component):
 
     def _on_alignment_set(self):
         w = self.widget
-        w.place_widget()
+        w.place_widget(self._bounds)
         w.update_traits()
 
     def _connect(self, obj):
