@@ -1,11 +1,11 @@
 """Draws a simple axes using tvtk.CubeAxesActor2D.
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005-2006, Enthought, Inc.
+# Copyright (c) 2005-2020, Enthought, Inc.
 # License: BSD Style.
 
 # Enthought library imports.
-from traits.api import Instance, Property, true
+from traits.api import Bool, Instance, Property
 from traitsui.api import View, Group, HGroup, \
         Item, BooleanEditor
 from tvtk.api import tvtk
@@ -15,6 +15,7 @@ from apptools.persistence import state_pickler
 from mayavi.core.module import Module
 from mayavi.core.pipeline_info import PipelineInfo
 
+
 ######################################################################
 # `CubeAxesActor2D` class.
 ######################################################################
@@ -24,7 +25,7 @@ class CubeAxesActor2D(tvtk.CubeAxesActor2D):
     """
 
     # Automaticaly fit the bounds of the axes to the data
-    use_data_bounds = true
+    use_data_bounds = Bool(True)
 
     input_info = PipelineInfo(datasets=['any'],
                               attribute_types=['any'],
@@ -52,7 +53,7 @@ class CubeAxesActor2D(tvtk.CubeAxesActor2D):
                             Item('use_data_bounds'),
                             HGroup(
                                  Item('bounds',
-                                    enabled_when='not use_data_bounds'),
+                                      enabled_when='not use_data_bounds'),
                                 ),
                             show_border=True),
                         Group(
@@ -64,16 +65,14 @@ class CubeAxesActor2D(tvtk.CubeAxesActor2D):
                             Item('font_factor'),
                             show_border=True),
                         HGroup(Item('show_actual_bounds',
-                                label='Use size bigger than screen',
-                                editor=BooleanEditor())),
+                                    label='Use size bigger than screen',
+                                    editor=BooleanEditor())),
                         Item('fly_mode'),
                         Item('corner_offset'),
                         Item('layer_number'),
-                       springy=True,
-                      ),
-                     scrollable=True,
-                     resizable=True,
-                     )
+                       springy=True),
+                       scrollable=True,
+                       resizable=True)
 
 
 ######################################################################
@@ -148,11 +147,11 @@ class Axes(Module):
         set the `actors` attribute up at this point.
         """
         # Create the axes and set things up.
-        axes = CubeAxesActor2D(number_of_labels= 2,
-                                    font_factor=1.5,
-                                    fly_mode='outer_edges',
-                                    corner_offset=0.0,
-                                    scaling=False)
+        axes = CubeAxesActor2D(number_of_labels=2,
+                               font_factor=1.5,
+                               fly_mode='outer_edges',
+                               corner_offset=0.0,
+                               scaling=False)
         axes.axis_title_text_property.shadow = False
         axes.axis_label_text_property.shadow = False
 
@@ -171,7 +170,7 @@ class Axes(Module):
             self.configure_input_data(self.axes, None)
             return
         src = mm.source
-        self.configure_input_data(self.axes, src.outputs[0])
+        self.configure_input(self.axes, src.outputs[0])
         self.pipeline_changed = True
 
     def update_data(self):
@@ -237,4 +236,3 @@ class Axes(Module):
             the actor to the source (if any). We are using it here.
         """
         self.update_pipeline()
-
