@@ -6,7 +6,7 @@ probably with the ImageData based renderers.
 
 """
 # Author: Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
-# Copyright (c) 2006, Enthought, Inc.
+# Copyright (c) 2006-2020, Enthought, Inc.
 # License: BSD Style.
 
 # Standard imports
@@ -15,9 +15,10 @@ from vtk.util import vtkConstants
 
 # Enthought library imports.
 from traits.api import Instance, Property, List, ReadOnly, \
-     Str, Button, Tuple
+     Str, Button, Tuple, Dict
 from traitsui.api import View, Group, Item, InstanceEditor
 from tvtk.api import tvtk
+from tvtk.common import suppress_vtk_warnings
 from tvtk.util.gradient_editor import hsva_to_rgba, GradientTable
 from tvtk.util.traitsui_gradient_editor import VolumePropertyEditor
 from tvtk.util.ctf import save_ctfs, load_ctfs, \
@@ -30,6 +31,8 @@ from mayavi.core.module import Module
 from mayavi.core.common import error
 from mayavi.core.trait_defs import DEnum
 from mayavi.core.lut_manager import LUTManager
+from mayavi.core.utils import DataSetHelper
+
 
 ######################################################################
 # Utility functions.
@@ -44,23 +47,28 @@ def is_volume_pro_available():
     else:
         return map.number_of_boards > 0
 
+
 def find_volume_mappers():
     res = []
-    for name in dir(tvtk):
-        if 'Volume' in name and 'Mapper' in name and 'OpenGL' not in name:
-            try:
-                klass = getattr(tvtk, name)
-                inst = klass()
-            except TypeError:
-                pass
-            else:
-                res.append(name)
+    with suppress_vtk_warnings():
+        obj = tvtk.Object()
+        obj.global_warning_display = False
+        for name in dir(tvtk):
+            if 'Volume' in name and 'Mapper' in name:
+                try:
+                    klass = getattr(tvtk, name)
+                    inst = klass()
+                except TypeError:
+                    pass
+                else:
+                    res.append(name)
     ignores = ['VolumeTextureMapper3D', 'VolumeProMapper']
     for name in ignores:
         if name in res:
             res.remove(name)
     return res
 
+
 def default_OTF(x1, x2):
     """Creates a default opacity transfer function.
     """
@@ -71,6 +79,7 @@ def default_OTF(x1, x2):
     otf.add_point(maxs, 0.2)
     return otf
 
+
 def make_CTF(x1, x2, hue_range=(2.0/3.0, 0.0),
              sat_range=(1.0, 1.0), val_range=(1.0, 1.0),
              n=10, mode='sqrt'):
@@ -95,7 +104,7 @@ def make_CTF(x1, x2, hue_range=(2.0/3.0, 0.0),
     if mode == 'sqrt':
         for i in range(n+1):
             # Generate x in [0, 1]
-            x = 0.5*(1.0  + cos((n-i)*pi/n)) # Chebyshev nodes.
+            x = 0.5*(1.0 + cos((n-i)*pi/n))  # Chebyshev nodes.
             h = hue_range[0] + dhue*x
             s = sat_range[0] + dsat*x
             v = val_range[0] + dval*x
@@ -104,7 +113,7 @@ def make_CTF(x1, x2, hue_range=(2.0/3.0, 0.0),
     elif mode == 'linear':
         for i in range(n+1):
             # Generate x in [0, 1]
-            x = float(i)/n # Uniform nodes.
+            x = float(i)/n  # Uniform nodes.
             h = hue_range[0] + dhue*x
             s = sat_range[0] + dsat*x
             v = val_range[0] + dval*x
@@ -267,6 +276,9 @@ class Volume(Module):
     # The opacity values.
     _otf = Instance(PiecewiseFunction)
 
+    # A cache for the mappers, a dict keyed by class.
+    _mapper_cache = Dict
+
     ######################################################################
     # `object` interface
     ######################################################################
@@ -337,18 +349,27 @@ class Volume(Module):
         if mm is None:
             return
 
-
         dataset = mm.source.get_output_dataset()
 
         ug = hasattr(tvtk, 'UnstructuredGridVolumeMapper')
-        if ug:
+        if dataset.is_a('vtkMultiBlockDataSet'):
+            if 'MultiBlockVolumeMapper' not in self._available_mapper_types:
+                error('Your version of VTK does not support '
+                      'Multiblock volume rendering')
+                return
+        elif dataset.is_a('vtkUniformGridAMR'):
+            if 'AMRVolumeMapper' not in self._available_mapper_types:
+                error('Your version of VTK does not support '
+                      'AMR volume rendering')
+                return
+        elif ug:
             if not dataset.is_a('vtkImageData') \
                    and not dataset.is_a('vtkUnstructuredGrid'):
-                error('Volume rendering only works with '\
+                error('Volume rendering only works with '
                       'StructuredPoints/ImageData/UnstructuredGrid datasets')
                 return
         elif not dataset.is_a('vtkImageData'):
-            error('Volume rendering only works with '\
+            error('Volume rendering only works with '
                   'StructuredPoints/ImageData datasets')
             return
 
@@ -373,11 +394,23 @@ class Volume(Module):
     ######################################################################
     # Non-public methods.
     ######################################################################
+    def _get_image_data_volume_mappers(self):
+        check = ('SmartVolumeMapper', 'GPUVolumeRayCastMapper',
+                 'OpenGLGPUVolumeRayCastMapper')
+        return [x for x in check
+                if x in self._available_mapper_types]
+
     def _setup_mapper_types(self):
         """Sets up the mapper based on input data types.
         """
         dataset = self.module_manager.source.get_output_dataset()
-        if dataset.is_a('vtkUnstructuredGrid'):
+        if dataset.is_a('vtkMultiBlockDataSet'):
+            if 'MultiBlockVolumeMapper' in self._available_mapper_types:
+                self._mapper_types = ['MultiBlockVolumeMapper']
+        elif dataset.is_a('vtkUniformGridAMR'):
+            if 'AMRVolumeMapper' not in self._available_mapper_types:
+                self._mapper_types = ['AMRVolumeMapper']
+        elif dataset.is_a('vtkUnstructuredGrid'):
             if hasattr(tvtk, 'UnstructuredGridVolumeMapper'):
                 check = ['UnstructuredGridVolumeZSweepMapper',
                          'UnstructuredGridVolumeRayCastMapper',
@@ -391,41 +424,46 @@ class Volume(Module):
                 self._mapper_types = mapper_types
                 return
         else:
+            mapper_types = self._get_image_data_volume_mappers()
             if dataset.point_data.scalars.data_type not in \
                [vtkConstants.VTK_UNSIGNED_CHAR,
                 vtkConstants.VTK_UNSIGNED_SHORT]:
                 if 'FixedPointVolumeRayCastMapper' \
                        in self._available_mapper_types:
-                    self._mapper_types = ['FixedPointVolumeRayCastMapper']
-                else:
-                    error('Available volume mappers only work with \
-                    unsigned_char or unsigned_short datatypes')
+                    mapper_types.append('FixedPointVolumeRayCastMapper')
+                elif len(mapper_types) == 0:
+                    error('Available volume mappers only work with '
+                          'unsigned_char or unsigned_short datatypes')
             else:
-                mapper_types = ['TextureMapper2D', 'RayCastMapper']
                 check = ['FixedPointVolumeRayCastMapper',
-                         'VolumeProMapper'
+                         'VolumeProMapper', 'TextureMapper2D', 'RayCastMapper',
+                         'TextureMapper3D'
                          ]
                 for mapper in check:
                     if mapper in self._available_mapper_types:
                         mapper_types.append(mapper)
-                self._mapper_types = mapper_types
+            self._mapper_types = mapper_types
 
     def _setup_current_range(self):
         mm = self.module_manager
         # Set the default name and range for our lut.
         lm = self.lut_manager
         slm = mm.scalar_lut_manager
-        lm.set(default_data_name=slm.default_data_name,
-               default_data_range=slm.default_data_range)
+        lm.trait_set(default_data_name=slm.default_data_name,
+                     default_data_range=slm.default_data_range)
 
         # Set the current range.
         dataset = mm.source.get_output_dataset()
-        sc = dataset.point_data.scalars
-        if sc is not None:
-            rng = sc.range
-        else:
+        dsh = DataSetHelper(dataset)
+        point_name, point_rng = dsh.get_range('scalars', 'point')
+        cell_name, cell_rng = dsh.get_range('scalars', 'cell')
+        if point_name is None and cell_name is None:
             error('No scalars in input data!')
             rng = (0, 255)
+        elif point_name is not None:
+            rng = point_rng
+        else:
+            rng = cell_rng
 
         if self.current_range != rng:
             self.current_range = rng
@@ -439,6 +477,16 @@ class Volume(Module):
     def _get_ray_cast_function(self):
         return self._ray_cast_function
 
+    def _get_mapper(self, klass):
+        """ Return a mapper of the given class. Either from the cache or by
+        making a new one.
+        """
+        result = self._mapper_cache.get(klass)
+        if result is None:
+            result = klass()
+            self._mapper_cache[klass] = result
+        return result
+
     def _volume_mapper_type_changed(self, value):
         mm = self.module_manager
         if mm is None:
@@ -447,37 +495,67 @@ class Volume(Module):
         old_vm = self._volume_mapper
         if old_vm is not None:
             old_vm.on_trait_change(self.render, remove=True)
+            try:
+                old_vm.remove_all_input_connections(0)
+            except AttributeError:
+                pass
 
         if value == 'RayCastMapper':
-            new_vm = tvtk.VolumeRayCastMapper()
+            new_vm = self._get_mapper(tvtk.VolumeRayCastMapper)
             self._volume_mapper = new_vm
             self._ray_cast_functions = ['RayCastCompositeFunction',
                                         'RayCastMIPFunction',
                                         'RayCastIsosurfaceFunction']
-            new_vm.volume_ray_cast_function = tvtk.VolumeRayCastCompositeFunction()
+            new_vm.volume_ray_cast_function = self._get_mapper(
+                tvtk.VolumeRayCastCompositeFunction
+            )
+        elif value == 'MultiBlockVolumeMapper':
+            new_vm = self._get_mapper(tvtk.MultiBlockVolumeMapper)
+            self._volume_mapper = new_vm
+            self._ray_cast_functions = ['']
+        elif value == 'AMRVolumeMapper':
+            new_vm = self._get_mapper(tvtk.AMRVolumeMapper)
+            self._volume_mapper = new_vm
+            self._ray_cast_functions = ['']
+        elif value == 'SmartVolumeMapper':
+            new_vm = self._get_mapper(tvtk.SmartVolumeMapper)
+            self._volume_mapper = new_vm
+            self._ray_cast_functions = ['']
+        elif value == 'GPUVolumeRayCastMapper':
+            new_vm = self._get_mapper(tvtk.GPUVolumeRayCastMapper)
+            self._volume_mapper = new_vm
+            self._ray_cast_functions = ['']
+        elif value == 'OpenGLGPUVolumeRayCastMapper':
+            new_vm = self._get_mapper(tvtk.OpenGLGPUVolumeRayCastMapper)
+            self._volume_mapper = new_vm
+            self._ray_cast_functions = ['']
         elif value == 'TextureMapper2D':
-            new_vm = tvtk.VolumeTextureMapper2D()
+            new_vm = self._get_mapper(tvtk.VolumeTextureMapper2D)
+            self._volume_mapper = new_vm
+            self._ray_cast_functions = ['']
+        elif value == 'TextureMapper3D':
+            new_vm = self._get_mapper(tvtk.VolumeTextureMapper3D)
             self._volume_mapper = new_vm
             self._ray_cast_functions = ['']
         elif value == 'VolumeProMapper':
-            new_vm = tvtk.VolumeProMapper()
+            new_vm = self._get_mapper(tvtk.VolumeProMapper)
             self._volume_mapper = new_vm
             self._ray_cast_functions = ['']
         elif value == 'FixedPointVolumeRayCastMapper':
-            new_vm = tvtk.FixedPointVolumeRayCastMapper()
+            new_vm = self._get_mapper(tvtk.FixedPointVolumeRayCastMapper)
             self._volume_mapper = new_vm
             self._ray_cast_functions = ['']
         elif value == 'UnstructuredGridVolumeRayCastMapper':
-            new_vm = tvtk.UnstructuredGridVolumeRayCastMapper()
+            new_vm = self._get_mapper(tvtk.UnstructuredGridVolumeRayCastMapper)
             self._volume_mapper = new_vm
             self._ray_cast_functions = ['']
         elif value == 'UnstructuredGridVolumeZSweepMapper':
-            new_vm = tvtk.UnstructuredGridVolumeZSweepMapper()
+            new_vm = self._get_mapper(tvtk.UnstructuredGridVolumeZSweepMapper)
             self._volume_mapper = new_vm
             self._ray_cast_functions = ['']
 
         src = mm.source
-        self.configure_connection(new_vm, src)
+        self.configure_input(new_vm, src.outputs[0])
         self.volume.mapper = new_vm
         new_vm.on_trait_change(self.render)
 
@@ -495,7 +573,7 @@ class Volume(Module):
             rcf.on_trait_change(self.render, remove=True)
 
         if len(new) > 0:
-            new_rcf = getattr(tvtk, 'Volume%s'%new)()
+            new_rcf = getattr(tvtk, 'Volume%s' % new)()
             new_rcf.on_trait_change(self.render)
             self._volume_mapper.volume_ray_cast_function = new_rcf
             self._ray_cast_function = new_rcf
