@@ -2,9 +2,10 @@
 Code to setup the preferences for common objects.
 """
 # Author: Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
-# Copyright (c) 2008-2015, Enthought Inc.
+# Copyright (c) 2008-2020, Enthought Inc.
 # License: BSD Style.
 
+import ast
 from .preference_manager import preference_manager
 
 
@@ -12,11 +13,11 @@ def get_scene_preferences():
     """Return a dictionary of the scene's default preferences."""
     pref = preference_manager.preferences
     res = {}
-    res['stereo'] = eval(pref.get('tvtk.scene.stereo'))
+    res['stereo'] = ast.literal_eval(pref.get('tvtk.scene.stereo'))
     res['magnification'] = \
-            eval(pref.get('tvtk.scene.magnification'))
-    res['foreground'] = eval(pref.get('tvtk.scene.foreground_color'))
-    res['background'] = eval(pref.get('tvtk.scene.background_color'))
+            ast.literal_eval(pref.get('tvtk.scene.magnification'))
+    res['foreground'] = ast.literal_eval(pref.get('tvtk.scene.foreground_color'))
+    res['background'] = ast.literal_eval(pref.get('tvtk.scene.background_color'))
     return res
 
 def set_scene_preferences(scene, prefs_dict=None):
@@ -26,6 +27,6 @@ def set_scene_preferences(scene, prefs_dict=None):
     if prefs_dict is None:
         prefs_dict = get_scene_preferences()
     # Set the preferences.
-    scene.set(**prefs_dict)
+    scene.trait_set(**prefs_dict)
     # If this isn't done the background isn't set.
     scene.renderer.background = scene.background
