@@ -97,7 +97,7 @@ class MayaviRootPreferencesPage(PreferencesPage):
     # Non-public interface.
     ######################################################################
     def __contrib_finder_default(self):
-        from contrib_finder import ContribFinder
+        from .contrib_finder import ContribFinder
         return ContribFinder()
 
 
@@ -130,15 +130,15 @@ class MayaviMlabPreferencesPage(PreferencesPage):
                    desc='the mlab backend to use')
 
     # The background color of the renderer.
-    background_color = Tuple(Range(0., 1., 1.), 
-                             Range(0., 1., 1.), 
+    background_color = Tuple(Range(0., 1., 1.),
+                             Range(0., 1., 1.),
                              Range(0., 1., 1.),
                              editor=RGBColorEditor,
                              desc='the background color of the scene')
 
     # The foreground color of the renderer.
-    foreground_color = Tuple(Range(0., 1., 0.), 
-                             Range(0., 1., 0.), 
+    foreground_color = Tuple(Range(0., 1., 0.),
+                             Range(0., 1., 0.),
                              Range(0., 1., 0.),
                              editor=RGBColorEditor,
                              desc='the foreground color of the scene')
@@ -159,4 +159,3 @@ class MayaviMlabPreferencesPage(PreferencesPage):
                              ),
                        resizable=True
                       )
-
