@@ -16,7 +16,6 @@ from mayavi.modules.grid_plane import GridPlane
 from mayavi.modules.axes import Axes
 from mayavi.filters.extract_grid import ExtractGrid
 from tvtk.api import tvtk
-from tvtk.common import is_old_pipeline
 
 class TestExtractGridFilter(unittest.TestCase):
 
@@ -41,8 +40,6 @@ class TestExtractGridFilter(unittest.TestCase):
         image_data = tvtk.ImageData(origin=(xmin, ymin, zmin),
                                     spacing=(dx, dy, dz),
                                     extent=(0, nx-1, 0, ny-1, 0, nz-1))
-        if is_old_pipeline():
-            image_data.whole_extent = image_data.extent
         src.data = image_data
         return src
 
@@ -87,10 +84,6 @@ class TestExtractGridFilter(unittest.TestCase):
         d = VTKDataSource()
         d.data = self.make_scatter()
         e.add_source(d)
-        if is_old_pipeline():
-            a = Axes()
-            e.add_module(a)
-            a.axes.number_of_labels = nb_ticks
 
         self.eg = eg
         self.gpx = gpx
@@ -108,8 +101,7 @@ class TestExtractGridFilter(unittest.TestCase):
     def test_extract_grid_filter_sample(self):
         import sys
         if sys.platform != "darwin":
-            from nose import SkipTest
-            raise SkipTest("actor.bounds returns incorrect values")
+            raise unittest.SkipTest("actor.bounds returns incorrect values")
         "Test if the sample rate works."
         eg = self.eg
         gpx = self.gpx
@@ -145,8 +137,7 @@ class TestExtractGridFilter(unittest.TestCase):
     def test_voi(self):
         import sys
         if sys.platform != "darwin":
-            from nose import SkipTest
-            raise SkipTest("actor.bounds returns incorrect values")
+            raise unittest.SkipTest("actor.bounds returns incorrect values")
         "Test if setting the VOI works correctly."
         eg = self.eg
         gpx = self.gpx
@@ -164,7 +155,7 @@ class TestExtractGridFilter(unittest.TestCase):
 
         # Now changing the VOI and then setting the ratio used to
         # show a stupid bug in the grid plane so we test that here.
-        eg.set(x_min=10, x_max=40)
+        eg.trait_set(x_min=10, x_max=40)
         eg.x_ratio = 5
 
         self.assertEqual(allclose(gpx.actor.actor.bounds,
@@ -175,11 +166,11 @@ class TestExtractGridFilter(unittest.TestCase):
                          (120.0, 180.0, 100.0, 200.0, 100.0, 100.0)), True)
 
         # Set some smaller VOI.
-        eg.set(y_min=20, y_max=40, z_min=10, z_max=30)
-        eg.set(x_ratio = 1, y_ratio=1, z_ratio=1)
+        eg.trait_set(y_min=20, y_max=40, z_min=10, z_max=30)
+        eg.trait_set(x_ratio = 1, y_ratio=1, z_ratio=1)
 
         # Reset it and it should go right back.
-        eg.set(x_min=0, x_max=50, y_min=0, y_max=50, z_min=0, z_max=50)
+        eg.trait_set(x_min=0, x_max=50, y_min=0, y_max=50, z_min=0, z_max=50)
         self.assertEqual(allclose(gpx.actor.actor.bounds,
                         (100.0, 100.0, 100.0, 200.0, 100.0, 200.0)), True)
         self.assertEqual(allclose(gpy.actor.actor.bounds,
