@@ -1,6 +1,6 @@
 # Author: Suyog Dutt Jain <suyog.jain@aero.iitb.ac.in>
 #         Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2008-2015,  Enthought, Inc.
+# Copyright (c) 2008-2020,  Enthought, Inc.
 # License: BSD Style.
 
 # Standard library imports.
@@ -9,7 +9,7 @@ from io import BytesIO
 import copy
 import numpy
 import unittest
-from mock import patch
+from unittest.mock import patch
 
 
 # Enthought library imports
