@@ -4,28 +4,43 @@ Integration tests of mlab with the null engine.
 This also tests some numerics with VTK.
 """
 
+import os
+import tempfile
 import unittest
-import mock
+from unittest.mock import patch
 
 import numpy as np
+from numpy.testing import assert_allclose
 from traits.testing.unittest_tools import UnittestTools
+from traits.api import push_exception_handler
+
+import vtk
 
 from mayavi import mlab
 from mayavi.core.engine import Engine
 from tvtk.api import tvtk
 from mayavi.tools.engine_manager import engine_manager
 from mayavi.core.registry import registry
+from mayavi.tests.common import get_example_data
+
+# XXX should probably be elsewhere
+push_exception_handler(reraise_exceptions=True)
 
 
-################################################################################
-# class `TestMlabNullEngine`
-################################################################################
 class TestMlabNullEngine(unittest.TestCase):
     """ Stub mlab to isolate as well as possible from creation of a new
         figure.
     """
 
+    def _stop_unregister_all_engines(self):
+        # Some tests leave around engines hanging around, so we clean them
+        # up to avoid strange test errors.
+        for engine in list(registry.engines.values()):
+            engine.stop()
+            registry.unregister_engine(engine)
+
     def setUp(self):
+        self._stop_unregister_all_engines()
         mlab.options.backend = 'test'
         e = mlab.get_engine()
         self.e = e
@@ -33,7 +48,7 @@ class TestMlabNullEngine(unittest.TestCase):
     def tearDown(self):
         # Check that the NullEngine is still the mlab engine
         current_engine = mlab.get_engine()
-        engine_overridden = not current_engine is self.e
+        engine_overridden = current_engine is not self.e
         engine_manager.current_engine = None
         self.e.stop()
         registry.unregister_engine(self.e)
@@ -43,12 +58,10 @@ class TestMlabNullEngine(unittest.TestCase):
             raise AssertionError("The NullEngine has been overridden")
 
 
-################################################################################
-# class `TestMlabNullEngineMisc`
-################################################################################
 class TestMlabNullEngineMisc(TestMlabNullEngine):
     """ Misc tests for mlab with the null engine
     """
+
     def test_contour_filter(self):
         a = np.zeros((3, 3, 3))
         a[1, 1, 1] = 1
@@ -59,9 +72,9 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
         x, y, z = filter.get_output_dataset().points.to_array().T
 
         # Check that the contour filter indeed did its work:
-        np.testing.assert_almost_equal(x, [ 2. ,  2. ,  1.5,  2.5,  2. ,  2. ])
-        np.testing.assert_almost_equal(y, [ 2. ,  1.5,  2. ,  2. ,  2.5,  2. ])
-        np.testing.assert_almost_equal(z, [ 1.5,  2. ,  2. ,  2. ,  2. ,  2.5])
+        np.testing.assert_almost_equal(x, [2., 2., 1.5, 2.5, 2., 2.])
+        np.testing.assert_almost_equal(y, [2., 1.5, 2., 2., 2.5, 2.])
+        np.testing.assert_almost_equal(z, [1.5, 2., 2., 2., 2., 2.5])
 
         # Check that the filter was not added to a live scene:
         if filter.scene is not None:
@@ -73,19 +86,20 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
         density = mlab.pipeline.user_defined(src, filter='GaussianSplatter')
 
         self.assertEqual(len(density.outputs), 1)
-        self.assertTrue(isinstance(density.get_output_dataset(), tvtk.ImageData))
+        self.assertTrue(
+            isinstance(density.get_output_dataset(), tvtk.ImageData)
+        )
 
     def test_mlab_source(self):
-        """ Check that the different objects created by mlab have an
-            'mlab_source' attribute.
-        """
         # Test for functions taking 3D scalar data
         pipelines = (
             (mlab.pipeline.scalar_scatter, ),
             (mlab.pipeline.scalar_field, ),
             (mlab.pipeline.scalar_field, mlab.pipeline.image_plane_widget),
             (mlab.contour3d, ),
-            (mlab.points3d, ), )
+            (mlab.volume_slice, ),
+            (mlab.points3d, ),
+        )
         data = np.random.random((3, 3, 3))
         for pipeline in pipelines:
             obj = pipeline[0](data)
@@ -99,17 +113,37 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
             (mlab.surf, ),
             (mlab.quiver3d, ),
             (mlab.pipeline.vector_scatter, ),
-            (mlab.pipeline.vector_scatter,
-                            mlab.pipeline.extract_vector_components),
-            (mlab.pipeline.vector_scatter,
-                            mlab.pipeline.extract_vector_norm),
-            (mlab.pipeline.array2d_source, ), )
+            (
+                mlab.pipeline.vector_scatter,
+                mlab.pipeline.extract_vector_components
+            ),
+            (mlab.pipeline.vector_scatter, mlab.pipeline.extract_vector_norm),
+            (mlab.pipeline.array2d_source, ),
+        )
         for pipeline in pipelines:
             obj = pipeline[0](x, y, z)
             for factory in pipeline[1:]:
                 obj = factory(obj)
             self.assertTrue(hasattr(obj, 'mlab_source'))
 
+    def test_strange_vmin_vmax(self):
+        tris = [[0, 1, 2]]
+        x, y, z = np.random.random((3, 3, 3))
+        mesh = mlab.pipeline.triangular_mesh_source(x, y, z, tris)
+        surf = mlab.pipeline.surface(mesh, vmin=100, vmax=101)
+
+    def test_add_dataset_works_with_vtk_datasets(self):
+        # Given
+        pd = vtk.vtkPolyData()
+        # When
+        mlab.pipeline.add_dataset(pd)
+        # Then
+        e = mlab.get_engine()
+        src = e.scenes[0].children[0]
+        from mayavi.sources.vtk_data_source import VTKDataSource
+        self.assertTrue(isinstance(src, VTKDataSource))
+        self.assertEqual(tvtk.to_vtk(src.data), pd)
+
     def test_figure(self):
         """ Various tests for mlab.figure().
         """
@@ -177,17 +211,15 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
         # test of the source, as to get a segfault, we need a module
         # opened on the source.
         n = 100
-        triangles = np.c_[np.arange(n-3),
-                            np.arange(n-3)+1,
-                            n-1-np.arange(n-3)]
+        triangles = np.c_[np.arange(n - 3),
+                          np.arange(n - 3) + 1, n - 1 - np.arange(n - 3)]
         x, y, z = np.random.random((3, n))
         src = mlab.triangular_mesh(x, y, z, triangles)
 
         # Now grow the mesh
         n = 1000
-        triangles = np.c_[np.arange(n-3),
-                            np.arange(n-3)+1,
-                            n-1-np.arange(n-3)]
+        triangles = np.c_[np.arange(n - 3),
+                          np.arange(n - 3) + 1, n - 1 - np.arange(n - 3)]
         x, y, z = np.random.random((3, n))
         src.mlab_source.reset(x=x, y=y, z=z, triangles=triangles)
 
@@ -200,16 +232,114 @@ class TestMlabNullEngineMisc(TestMlabNullEngine):
         s2 = mlab.surf(a, color=(0, 0, 0))
         mlab.colorbar()
         self.assertEqual(
-                    s2.module_manager.scalar_lut_manager.show_scalar_bar,
-                    False)
+            s2.module_manager.scalar_lut_manager.show_scalar_bar, False
+        )
         self.assertEqual(
-                    s1.module_manager.scalar_lut_manager.show_scalar_bar,
-                    True)
+            s1.module_manager.scalar_lut_manager.show_scalar_bar, True
+        )
+
+    def test_source_can_save_output_to_file(self):
+        # Given
+        x, y, z = np.random.random((3, 100))
+        src = mlab.pipeline.scalar_scatter(x, y, z)
+
+        # When
+        tmpfname = tempfile.mktemp('.vtk')
+        src.save_output(tmpfname)
+
+        # Then
+        self.assertTrue(os.path.exists(tmpfname))
+
+        # Cleanup
+        if os.path.exists(tmpfname):
+            os.remove(tmpfname)
+
+    def test_slice_unstructured_grid(self):
+        # Given
+        src = mlab.pipeline.open(get_example_data('uGridEx.vtk'))
+        eg = mlab.pipeline.extract_unstructured_grid(src)
+        eg.filter.trait_set(cell_clipping=True, cell_maximum=2)
+
+        # When
+        sug = mlab.pipeline.slice_unstructured_grid(eg)
+
+        # Then
+        assert_allclose(sug.actor.actor.bounds, (1.0, 2.0, 0.0, 1.0, 0.0, 1.0))
+
+    def test_set_active_attribute(self):
+        # Given
+        x, y = np.mgrid[0:10:100j, 0:10:100j]
+        z = x**2 + y**2
+        w = np.arctan(x / (y + 0.1))
+
+        # Create the data source
+        src = mlab.pipeline.array2d_source(z)
+
+        # add second array
+        dataset = src.mlab_source.dataset
+        scalar_range = dataset.point_data.scalars.range
+        array_id = dataset.point_data.add_array(w.T.ravel())
+        dataset.point_data.get_array(array_id).name = 'color'
+        dataset.point_data.update()
+
+        # select the array from a copy
+        # When/Then
+        f = mlab.pipeline.set_active_attribute(dataset, point_scalars='color')
+        self.assertFalse(
+            np.allclose(
+                f.get_output_dataset().point_data.scalars.range, scalar_range
+            )
+        )
+
+
+class TestSourceReset(TestMlabNullEngine):
+    def test_glyph_reset_twice_with_fewer_points(self):
+        # Given
+        x, y, z = np.random.random((3, 100))
+        g = mlab.quiver3d(x, y, z, x, y, z)
+        src = g.mlab_source
+
+        # When/Then
+        x, y, z = np.random.random((3, 5))
+        src.reset(x=x, y=y, z=z, u=x, v=y, w=z)
+
+    def test_lines_reset_twice_with_fewer_points(self):
+        # Given
+        t = np.linspace(0, 10, 100)
+        x, y = np.cos(t), np.sin(t)
+        l = mlab.plot3d(x, y, t, t)
+
+        # When/Then
+        t = np.linspace(0, 10, 5)
+        x, y = np.cos(t), np.sin(t)
+        # If this works without a segfault, we are good.
+        l.mlab_source.reset(x=x, y=y, z=t, scalars=t)
+
+    def test_mesh_reset_twice_with_fewer_points(self):
+        # Given
+        x, y = np.mgrid[0:1:10j, 0:1:10j]
+        surf = mlab.mesh(x, y, x+y)
+
+        # When/Then
+        x, y = np.mgrid[0:1:2j, 0:1:2j]
+        # If this works without a segfault, we are good.
+        surf.mlab_source.reset(x=x, y=y, z=x+y, scalars=(x+y))
+
+    def test_trimesh_reset_twice_with_fewer_points(self):
+        # Given
+        x, y, z = np.random.random((3, 100))
+        cells = np.random.randint(0, 100, 300)
+        cells.resize((100, 3))
+        surf = mlab.triangular_mesh(x, y, z, cells)
+
+        # When/Then
+        x, y, z = np.random.random((3, 5))
+        cells = np.random.randint(0, 5, 15)
+        cells.resize((5, 3))
+        # If this works without a segfault, we are good.
+        surf.mlab_source.reset(x=x, y=y, z=z, triangles=cells)
 
 
-################################################################################
-# class `TestMlabPipeline`
-################################################################################
 class TestMlabPipeline(TestMlabNullEngine):
     """ Test the pipeline functions.
         For vtk versions greater than 5.10, widgets need
@@ -219,23 +349,13 @@ class TestMlabPipeline(TestMlabNullEngine):
     """
 
     def setUp(self):
-        ver = tvtk.Version()
-        self.less_than_or_equal_to_vtk_5_10 = True
-        if ver.vtk_major_version >= 5 and ver.vtk_minor_version > 10:
-            self.less_than_or_equal_to_vtk_5_10 = False
-        if self.less_than_or_equal_to_vtk_5_10:
-            super(TestMlabPipeline, self).setUp()
-        else:
-            e = Engine()
-            e.start()
-            mlab.set_engine(e)
+        e = Engine()
+        e.start()
+        mlab.set_engine(e)
 
     def tearDown(self):
-        if self.less_than_or_equal_to_vtk_5_10:
-            super(TestMlabPipeline, self).tearDown()
-        else:
-            for engine in list(registry.engines.keys()):
-                registry.unregister_engine(engine)
+        for engine in list(registry.engines.keys()):
+            registry.unregister_engine(engine)
 
     def test_probe_data(self):
         """ Test probe_data
@@ -245,18 +365,14 @@ class TestMlabPipeline(TestMlabNullEngine):
         iso = mlab.contour3d(x, y, z, r)
         x_, y_, z_ = np.random.random((3, 10, 4, 2))
         r_ = mlab.pipeline.probe_data(iso, x_, y_, z_)
-        np.testing.assert_array_almost_equal(r_,
-                                             np.sqrt(x_**2 + y_**2 + z_**2),
-                                             decimal=1)
+        np.testing.assert_array_almost_equal(
+            r_, np.sqrt(x_**2 + y_**2 + z_**2), decimal=1
+        )
         flow = mlab.flow(x, y, z, x, y, z)
-        u_, v_, w_ = mlab.pipeline.probe_data(flow, x_, y_, z_,
-                                              type='vectors')
-        np.testing.assert_array_almost_equal(u_, x_,
-                                             decimal=2)
-        np.testing.assert_array_almost_equal(v_, y_,
-                                             decimal=2)
-        np.testing.assert_array_almost_equal(w_, z_,
-                                             decimal=3)
+        u_, v_, w_ = mlab.pipeline.probe_data(flow, x_, y_, z_, type='vectors')
+        np.testing.assert_array_almost_equal(u_, x_, decimal=2)
+        np.testing.assert_array_almost_equal(v_, y_, decimal=2)
+        np.testing.assert_array_almost_equal(w_, z_, decimal=3)
 
 
 ################################################################################
@@ -284,25 +400,29 @@ class TestMlabHelperFunctions(TestMlabNullEngine, UnittestTools):
         obj = mlab.imshow(s)
 
     def test_imshow_extent(self):
-        mlab.imshow(np.random.rand(10, 20),
-                    extent=[-1, 11, -1, 21, 0, 0])
+        mlab.imshow(np.random.rand(10, 20), extent=[-1, 11, -1, 21, 0, 0])
 
     def test_imshow_colormap(self):
         # Check if the pipeline is refreshed when we change colormap.
         # See issue #262
-        a = np.random.random_integers(0, 10, (100, 100))
+        a = np.random.randint(0, 10 + 1, (100, 100))
 
         actor = mlab.imshow(a, colormap="cool")
 
         with self.assertTraitChanges(actor, 'pipeline_changed'):
             actor.module_manager.scalar_lut_manager.lut_mode = 'jet'
 
-################################################################################
-# class `TestMlabModules`
-################################################################################
+    def test_volume_slice(self):
+        x, y, z = np.ogrid[-5:5:20j, -5:5:20j, -5:5:20j]
+        scalars = x * x * 0.5 + y * y + z * z * 2.0
+        ipw = mlab.volume_slice(scalars, plane_orientation='y_axes')
+        self.assertEqual(ipw.ipw.plane_orientation, 'y_axes')
+
+
 class TestMlabModules(TestMlabNullEngine):
     """ Test the mlab modules.
     """
+
     def test_volume(self):
         """ Test the mlab volume factory.
         """
@@ -317,9 +437,9 @@ class TestMlabModules(TestMlabNullEngine):
             # use allclose() to match the tuples.
             np.allclose(vol._ctf.get_color(value), color)
         # Test the vmin and vmax features
-        for value in 0.5*np.random.random(10):
+        for value in 0.5 * np.random.random(10):
             self.assertEqual(vol._otf.get_value(value), 0)
-        for value in (0.9+0.1*np.random.random(10)):
+        for value in (0.9 + 0.1 * np.random.random(10)):
             self.assertEqual(vol._otf.get_value(value), 0.2)
         # Test the rescaling of the colormap when using vmin and vmax
         # Rmq: we have to be careful: the range of the ctf can change
@@ -327,20 +447,22 @@ class TestMlabModules(TestMlabNullEngine):
         range1 = vol1._ctf.range[1] - vol1._ctf.range[0]
         vol2 = mlab.pipeline.volume(src, vmin=0.25, vmax=0.75)
         range2 = vol2._ctf.range[1] - vol2._ctf.range[0]
-        for value in 0.5*np.random.random(10):
+        for value in np.random.random(10):
             np.testing.assert_array_almost_equal(
-                        vol1._ctf.get_color(2*range1*value),
-                        vol2._ctf.get_color(0.25+range2*value))
+                vol1._ctf.get_color(range1 * value),
+                vol2._ctf.get_color(0.25 + 0.5 * range2 * value)
+            )
         # Test outside the special [0, 1] range
-        src = mlab.pipeline.scalar_field(2*scalars)
+        src = mlab.pipeline.scalar_field(2 * scalars)
         vol1 = mlab.pipeline.volume(src)
         range1 = vol1._ctf.range[1] - vol1._ctf.range[0]
         vol2 = mlab.pipeline.volume(src, vmin=0.5, vmax=1.5)
         range2 = vol2._ctf.range[1] - vol2._ctf.range[0]
         for value in np.random.random(10):
             np.testing.assert_array_almost_equal(
-                        vol1._ctf.get_color(2*range1*value),
-                        vol2._ctf.get_color(0.5+range2*value))
+                vol1._ctf.get_color(2 * range1 * value),
+                vol2._ctf.get_color(0.5 + range2 * value)
+            )
 
     def test_text(self):
         """ Test the text module.
@@ -360,9 +482,17 @@ class TestMlabModules(TestMlabNullEngine):
         """
         data = np.random.random((3, 3, 3))
         src = mlab.pipeline.scalar_field(data)
-        t = mlab.text3d(0, 0, 0, 'foo', opacity=0.5, scale=2,
-                    orient_to_camera=False, color=(0, 0, 0),
-                    orientation=(90, 0, 0))
+        t = mlab.text3d(
+            0,
+            0,
+            0,
+            'foo',
+            opacity=0.5,
+            scale=2,
+            orient_to_camera=False,
+            color=(0, 0, 0),
+            orientation=(90, 0, 0)
+        )
 
     def test_contour_grid_plane(self):
         """Test the contour_grid_plane.
@@ -376,26 +506,32 @@ class TestMlabModules(TestMlabNullEngine):
     def test_barchart(self):
         """Test the barchart function."""
 
-        s = np.abs(np.random.random((3,3)))
+        s = np.abs(np.random.random((3, 3)))
         b = mlab.barchart(s)
-        self.assertEqual(b.glyph.glyph.scale_mode,
-                         'scale_by_vector_components')
+        self.assertEqual(
+            b.glyph.glyph.scale_mode, 'scale_by_vector_components'
+        )
         s += 1
         b.mlab_source.update()
-        self.assertEqual(b.glyph.glyph.scale_mode,
-                         'scale_by_vector_components')
+        self.assertEqual(
+            b.glyph.glyph.scale_mode, 'scale_by_vector_components'
+        )
+
+    def test_axes(self):
+        s = mlab.test_plot3d()
+        a = mlab.axes(s)
+        assert_allclose(
+            a.axes.ranges, [-1.5, 1.5, -1.5, 1.5, -0.5, 0.5], rtol=0, atol=0.1
+        )
 
 
-################################################################################
-# class `TestMlabAnimate`
-################################################################################
 class TestMlabAnimate(TestMlabNullEngine):
-
     def test_animate_sets_up_movie_maker(self):
         # Given
-        @mlab.animate
+        @mlab.animate(ui=False)
         def anim():
-            for i in range(5): yield
+            for i in range(5):
+                yield
 
         self.e.new_scene()
         from mayavi.tests.test_file_timestep import make_mock_scene
@@ -404,7 +540,7 @@ class TestMlabAnimate(TestMlabNullEngine):
 
         # When
         from mayavi.core.file_data_source import NoUITimer
-        with mock.patch('mayavi.tools.animator.Timer', NoUITimer):
+        with patch('mayavi.tools.animator.Timer', NoUITimer):
             a = anim()
             a.timer.Start()
 
