@@ -4,9 +4,10 @@ refactored to move to AppTools however we repeat the tests here with a
 TVTK object to ensure that the test works with TVTK objects.
 """
 # Author: Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
-# Copyright (c) 2008, Enthought, Inc.
+# Copyright (c) 2008-2020, Enthought, Inc.
 # License: BSD Style.
 
+import sys
 import unittest
 
 from traits.api import (HasTraits, Float, Instance,
@@ -45,11 +46,13 @@ class Child(HasTraits):
     def not_recordable(self):
         pass
 
+
 class Parent(HasTraits):
     children = List(Child, record=True)
     recorder = Instance(Recorder, record=False)
 
-class Test(HasTraits):
+
+class _Test(HasTraits):
     # This should be set.
     recorder = Instance(HasTraits)
 
@@ -150,8 +153,6 @@ class TestRecorder(unittest.TestCase):
         toy.type = 'rat'
         self.assertEqual(tape.lines[-1], "child.toy.type = 'teddy'")
 
-        #print tape.script
-
         # Stop recording.
         n = len(tape.lines)
         tape.unregister(p)
@@ -289,7 +290,7 @@ class TestRecorder(unittest.TestCase):
 
     def test_recorder_and_ignored(self):
         "Test if recorder trait is set and private traits are ignored."
-        t = Test()
+        t = _Test()
         self.assertEqual(t.recorder, None)
         self.assertEqual(t._ignore, False)
         self.assertEqual(t.ignore_, False)
@@ -438,8 +439,8 @@ class TestRecorder(unittest.TestCase):
         tape.recording = False
         tape.unregister(p)
 
-        import StringIO
-        f = StringIO.StringIO()
+        import io
+        f = io.StringIO()
         tape.save(f)
         # Test if the file is OK.
         expect = ["child = parent.children[0]\n",
