@@ -2,19 +2,19 @@
 from numpy import ones, resize, linspace, atleast_3d
 
 from traits.api import Property, Str, Button, Trait, \
-    Any, Instance, HasStrictTraits, false, Dict, HasTraits, \
+    Any, Instance, HasStrictTraits, Dict, HasTraits, \
     CArray, Bool
 from traitsui.api import EnumEditor, View, Item, HGroup, \
     VGroup, spring, Group, TextEditor, HTMLEditor, InstanceEditor, \
     TabularEditor, TitleEditor, Label, ArrayEditor, ImageEditor
 
 from traitsui.tabular_adapter import TabularAdapter
-from traitsui.image.image import ImageLibrary
 
 from pyface.api import ImageResource
+from pyface.image.image import ImageLibrary
 
-from data_source_factory import DataSourceFactory
-from preview_window import PreviewWindow
+from .data_source_factory import DataSourceFactory
+from .preview_window import PreviewWindow
 from mayavi.modules.api import Surface, Glyph
 from mayavi.filters.api import ExtractEdges
 
@@ -101,7 +101,7 @@ class DataSourceWizard(HasTraits):
     grid_shape = CArray(shape=(3,), dtype='i')
 
     # Whether or not the data points should be connected.
-    lines = false
+    lines = Bool(False)
 
     # The scalar data selection
     scalar_data = Str('', help="Select the array that gives the value of the "
@@ -118,10 +118,11 @@ class DataSourceWizard(HasTraits):
 
     connectivity_triangles = Str
 
-    has_vector_data = false(help="""Do you want to plot vector components?""")
+    has_vector_data = Bool(False, help="Do you want to plot "
+                                    "vector components?")
 
     # A boolean to ask the user if he wants to load scalar data
-    has_scalar_data = false
+    has_scalar_data = Bool(False)
 
     vector_u = Str
 
