@@ -4,7 +4,7 @@ pipeline in a procedural way.
 """
 
 # Author: Gael Varoquaux
-# Copyright (c) 2007-2015 Enthought, Inc.
+# Copyright (c) 2007-2020 Enthought, Inc.
 # License: BSD Style.
 
 import numbers
@@ -13,11 +13,12 @@ import numpy as np
 
 # Enthought library imports.
 from traits.api import String, CFloat, Instance, HasTraits, \
-            Trait, CArray, true, Any, Range, Either
+            Trait, CArray, Bool, Any, Range, Either
 from . import tools
 from .figure import draw, gcf
 
 # Mayavi imports
+from mayavi.core.utils import DataSetHelper
 import mayavi.modules.api as modules
 from .pipe_base import make_function
 from .modules import ModuleFactory
@@ -261,7 +262,7 @@ class SingletonModuleFactory(ModuleFactory):
 
         # Now calling the traits setter, so that traits handlers are
         # called
-        self.set(**kwargs)
+        self.trait_set(**kwargs)
         if self._scene.scene is not None:
             self._scene.scene.disable_render = False
 
@@ -351,13 +352,13 @@ class Axes(AxesLikeModuleFactory):
                             Ranges of the labels displayed on the axes.
                             Default is the object's extents.""", )
 
-    x_axis_visibility = true(adapts='axes.x_axis_visibility',
+    x_axis_visibility = Bool(True, adapts='axes.x_axis_visibility',
                 help="Whether or not the x axis is visible (boolean)")
 
-    y_axis_visibility = true(adapts='axes.y_axis_visibility',
+    y_axis_visibility = Bool(True, adapts='axes.y_axis_visibility',
                 help="Whether or not the y axis is visible (boolean)")
 
-    z_axis_visibility = true(adapts='axes.z_axis_visibility',
+    z_axis_visibility = Bool(True, adapts='axes.z_axis_visibility',
                 help="Whether or not the z axis is visible (boolean)")
 
     _target = Instance(modules.Axes, ())
@@ -369,8 +370,8 @@ class Axes(AxesLikeModuleFactory):
         axes.axes.use_data_bounds = False
         axes.axes.bounds = self.extent
         if self.ranges is None:
-            axes.axes.ranges = \
-                axes.module_manager.source.outputs[0].bounds
+            dsh = DataSetHelper(axes.module_manager.source.outputs[0])
+            axes.axes.ranges = dsh.get_bounds()
 
     def _ranges_changed(self):
         if self.ranges is not None:
@@ -447,7 +448,7 @@ class Text(ModuleFactory):
         x, and y are the position of the origin of the text. If no z
         keyword argument is given, x and y are the 2D projection of the
         figure, they belong to [0, 1]. If a z keyword  argument is given, the
-        text is positionned in 3D, in figure coordinnates.
+        text is positioned in 3D, in figure coordinates.
         """
 
     width = Trait(None, None, CFloat, adapts='width',
@@ -467,7 +468,7 @@ class Text(ModuleFactory):
         if 'z' in kwargs and kwargs['z'] is not None:
             self._target.z_position = kwargs['z']
             self._target.position_in_3d = True
-        elif not (x < 1. and x > 0. and y > 0. and y < 1.):
+        elif not (x <= 1. and x >= 0. and y >= 0. and y <= 1.):
             raise ValueError('Text positions should be in [0, 1] if no z'
                 'position is given')
         super(Text, self).__init__(None, **kwargs)
@@ -488,7 +489,7 @@ class Text3D(ModuleFactory):
             text3d(x, y, z, text, ...)
 
         x, y, and z are the position of the origin of the text. The
-        text is positionned in 3D, in figure coordinnates.
+        text is positioned in 3D, in figure coordinates.
         """
 
     _target = Instance(modules.Text3D, ())
@@ -504,7 +505,7 @@ class Text3D(ModuleFactory):
                         camera. If not, these angles are referenced to
                         the z axis.""")
 
-    orient_to_camera = true(adapts='orient_to_camera',
+    orient_to_camera = Bool(True, adapts='orient_to_camera',
                         desc="""if the text is kept oriented to the
                         camera, or is pointing in a specific direction,
                         regardless of the camera position.""")
