@@ -8,13 +8,13 @@ helper functions.
 
 # Author: Gael Varoquaux <gael.varoquaux@normalesup.org>
 #         Prabhu Ramachandran
-# Copyright (c) 2007-2015, Enthought, Inc.
+# Copyright (c) 2007-2020, Enthought, Inc.
 # License: BSD Style.
 
 import numpy
 
 from traits.api import Trait, CArray, Instance, CFloat, \
-    Any, false, true, TraitTuple, Range, Bool, Property, CInt, Enum, Either
+    Any, Tuple, Range, Bool, Property, CInt, Enum, Either
 from traits.trait_errors import TraitError
 from tvtk.api import tvtk
 from tvtk.common import camel2enthought
@@ -42,7 +42,7 @@ __all__ = ['vectors', 'glyph', 'streamline', 'surface', 'iso_surface',
 class ModuleFactory(PipeFactory):
     """ Base class for all the modules factories"""
     color = Trait(None, None,
-                TraitTuple(Range(0., 1.), Range(0., 1.), Range(0., 1.)),
+                Tuple(Range(0., 1.), Range(0., 1.), Range(0., 1.)),
                 help="""the color of the vtk object. Overides the colormap,
                         if any, when specified. This is specified as a
                         triplet of float ranging from 0 to 1, eg (1, 1,
@@ -86,7 +86,7 @@ class DataModuleFactory(ModuleFactory):
     """ Base class for all the module factories operating on data (ie not
         text and outline) """
 
-    reset_zoom = true(help="""Reset the zoom to accomodate the data newly
+    reset_zoom = Bool(True, help="""Reset the zoom to accomodate the data newly
                         added to the scene. Defaults to True.""")
 
     extent = CArray(shape=(6,),
@@ -98,8 +98,8 @@ class DataModuleFactory(ModuleFactory):
     def _extent_changed(self):
         tools.set_extent(self._target, self.extent)
 
-    transparent = false(help="""make the opacity of the actor depend on the
-                               scalar.""")
+    transparent = Bool(False, help="""make the opacity of the actor depend on
+                                    the scalar.""")
 
     def _transparent_changed(self):
         if self.transparent:
@@ -143,10 +143,16 @@ class DataModuleFactory(ModuleFactory):
                     = False
         vmin, vmax = \
                 self._target.module_manager.scalar_lut_manager.data_range
+        # This takes care of pathological cases where vmin is changed
+        # before vmax is changed, but vmin is greater than data_range[1]
         if self.vmin is not None:
             vmin = self.vmin
+            if self.vmax is None:
+                vmax = max(vmax, vmin)
         if self.vmax is not None:
             vmax = self.vmax
+            if self.vmin is None:
+                vmin = min(vmin, vmax)
         self._target.module_manager.scalar_lut_manager.data_range = \
                         (vmin, vmax)
 
@@ -181,7 +187,7 @@ class ContourModuleFactory(DataModuleFactory):
             assert type(self.contours) == int, \
                             "The contours argument must be an integer"
             assert self.contours > 0, "The contours argument must be positive"
-            self._target.contour.set(auto_contours=True,
+            self._target.contour.trait_set(auto_contours=True,
                                 number_of_contours=self.contours)
         if hasattr(self._target, 'enable_contours'):
             self._target.enable_contours = True
@@ -345,15 +351,23 @@ class StreamlineFactory(DataModuleFactory):
             desc="The direction of the integration.",
             )
 
+    def _anytrait_changed(self, name, value):
+        if name == 'seed_visible' and self._target.scene is None:
+            pass
+        else:
+            super(StreamlineFactory, self)._anytrait_changed(name, value)
+
     def _seedtype_changed(self):
         # XXX: this also acts for seed_scale and seed_resolution, but no
         # need to define explicit callbacks, as all the callbacks are
         # being called anyhow.
         self._target.seed.widget = widget = \
                             self._target.seed.widget_list[self.seedtype_]
+        scene = self._target.scene
 
         if not self.seed_scale == 1.:
-            widget.enabled = True
+            if scene is not None:
+                widget.enabled = True
             if self.seedtype == 'line':
                 p1 = widget.point1
                 p2 = widget.point2
@@ -375,10 +389,12 @@ class StreamlineFactory(DataModuleFactory):
             # propagate changes.
             self._target.seed.stop()
             self._target.seed.start()
-            widget.enabled = self.seed_visible
+            if scene is not None:
+                widget.enabled = self.seed_visible
 
         if self.seed_resolution is not None:
-            widget.enabled = True
+            if scene is not None:
+                widget.enabled = True
             if self.seedtype in ('plane', 'line'):
                 widget.resolution = self.seed_resolution
             elif self.seedtype == 'sphere':
@@ -389,7 +405,8 @@ class StreamlineFactory(DataModuleFactory):
             # propagate changes.
             self._target.seed.stop()
             self._target.seed.start()
-            widget.enabled = self.seed_visible
+            if scene is not None:
+                widget.enabled = self.seed_visible
 
 
 streamline = make_function(StreamlineFactory)
@@ -461,7 +478,7 @@ class ImagePlaneWidgetFactory(DataModuleFactory):
     _target = Instance(modules.ImagePlaneWidget, ())
 
     slice_index = CInt(0, adapts='ipw.slice_index',
-                        help="""The index along wich the
+                        help="""The index along with the
                                             image is sliced.""")
 
     plane_opacity = Range(0.0, 1.0, 1.0, adapts='ipw.plane_property.opacity',
@@ -552,7 +569,7 @@ class VolumeFactory(PipeFactory):
     """
 
     color = Trait(None, None,
-                TraitTuple(Range(0., 1.), Range(0., 1.), Range(0., 1.)),
+                Tuple(Range(0., 1.), Range(0., 1.), Range(0., 1.)),
                 help="""the color of the vtk object. Overides the colormap,
                         if any, when specified. This is specified as a
                         triplet of float ranging from 0 to 1, eg (1, 1,
@@ -570,7 +587,7 @@ class VolumeFactory(PipeFactory):
 
     _target = Instance(modules.Volume, ())
 
-    __ctf_rescaled = Bool(False)
+    __last_vrange = Any(None)
 
     ######################################################################
     # Non-public interface.
@@ -616,15 +633,25 @@ class VolumeFactory(PipeFactory):
         otf.add_point(vmax, 0.2)
         self._target._otf = otf
         self._target._volume_property.set_scalar_opacity(otf)
-        if self.color is None and not self.__ctf_rescaled and \
-                        ((self.vmin is not None) or (self.vmax is not None)):
+        if self.color is None and \
+           ((self.vmin is not None) or (self.vmax is not None)):
             # FIXME: We don't use 'rescale_ctfs' because it screws up the
-            # nodes.
+            # nodes, this is because, the values are actually scaled between
+            # the specified vmin/vmax and NOT the full range of values
+            # specified in the CTF or in the volume object.
+            if self.__last_vrange:
+                last_min, last_max = self.__last_vrange
+            else:
+                last_min, last_max = range_min, range_max
 
             def _rescale_value(x):
-                nx = (x - range_min) / (range_max - range_min)
+                nx = (x - last_min) / (last_max - last_min)
                 return vmin + nx * (vmax - vmin)
-            # The range of the existing ctf can vary.
+
+            # For some reason on older versions of VTK (< 8.1 at least),
+            # The range trait is not updated correctly when the rgb points
+            # are added, this causes problems so we explicitly update them.
+            self._target._ctf.update_traits()
             scale_min, scale_max = self._target._ctf.range
 
             def _rescale_node(x):
@@ -656,12 +683,12 @@ class VolumeFactory(PipeFactory):
 
             self._target._ctf = ctf
             self._target._volume_property.set_color(ctf)
-            self.__ctf_rescaled = True
+            self.__last_vrange = vmin, vmax
 
         self._target.update_ctf = True
 
     # This is not necessary: the job is already done by _vmin_changed
-    #_vmax_changed = _vmin_changed
+    _vmax_changed = _vmin_changed
 
 volume = make_function(VolumeFactory)
 
