@@ -4,7 +4,7 @@ Base class for factories for adding objects to the pipeline.
 """
 
 # Author: Gael Varoquaux <gael.varoquaux@normalesup.org>
-# Copyright (c) 2007-2015, Enthought, Inc.
+# Copyright (c) 2007-2020, Enthought, Inc.
 # License: BSD Style.
 
 import warnings
@@ -134,7 +134,7 @@ class PipeFactory(HasPrivateTraits):
         if self.figure is not None and self.figure is not self._scene:
             warnings.warn('Trying to add a module on the wrong scene')
         if isinstance(parent, (Source, tvtk.DataSet)) \
-                and not isinstance(parent, Filter) and scene is not None:
+                and not isinstance(parent, Filter) and self._scene is not None:
             # Search the current scene to see if the  source is already
             # in it, if not add it.
             if not parent in self._scene.children:
@@ -154,21 +154,25 @@ class PipeFactory(HasPrivateTraits):
             self._target.add_trait('mlab_source', Instance(ms.__class__))
             self._target.mlab_source = ms
 
-        traits = self.get(self.class_trait_names())
+        traits = self.trait_get(self.class_trait_names())
         [traits.pop(key) for key in list(traits.keys())
                                     if key[0] == '_' or key is None]
         traits.update(kwargs)
         # Now calling the traits setter, so that traits handlers are
         # called
-        self.set(**traits)
+        self.trait_set(**traits)
         if scene is not None:
             scene.disable_render = not self._do_redraw
 
     def set(self, trait_change_notify=True, **traits):
+        return self.trait_set(trait_change_notify=trait_change_notify,
+                              **traits)
+
+    def trait_set(self, trait_change_notify=True, **traits):
         """ Same as HasTraits.set except that notification is forced,
         unless trait_change_notify==False"""
-        HasPrivateTraits.set(self, trait_change_notify=trait_change_notify,
-                                    **traits)
+        HasPrivateTraits.trait_set(
+            self, trait_change_notify=trait_change_notify, **traits)
         if trait_change_notify == False:
             return
         for trait in traits:
