@@ -7,7 +7,7 @@ import numpy as np
 
 from tvtk.api import tvtk
 from . import tools
-
+import tvtk.common as tvtk_common
 
 def probe_data(mayavi_object, x, y, z, type='scalars', location='points'):
     """ Retrieve the data from a described by Mayavi visualization object
@@ -49,8 +49,8 @@ def probe_data(mayavi_object, x, y, z, type='scalars', location='points'):
                                                    z.ravel()])
     shape = list(shape)
     probe = tvtk.ProbeFilter()
-    probe.input = probe_data
-    probe.source = dataset
+    tvtk_common.configure_input_data(probe, probe_data)
+    tvtk_common.configure_source_data(probe, dataset)
     probe.update()
 
     if location == 'points':
