@@ -4,7 +4,7 @@ Data sources classes and their associated functions for mlab.
 
 # Author: Gael Varoquaux <gael.varoquaux@normalesup.org>
 #         Prabhu Ramachandran
-# Copyright (c) 2007-2010, Enthought, Inc.
+# Copyright (c) 2007-2020, Enthought, Inc.
 # License: BSD Style.
 
 import numpy as np
@@ -70,8 +70,12 @@ class MlabSource(HasTraits):
             self.dataset.modified()
             md = self.m_data
             if md is not None:
-                if hasattr(md, '_assign_attribute'):
-                    md._assign_attribute.update()
+                aa = getattr(md, '_assign_attribute', None)
+                vectors = getattr(self, 'vectors', None)
+                scalars = getattr(self, 'scalars', None)
+                if aa is not None and (scalars is not None or
+                                       vectors is not None):
+                    aa.update()
                 md.data_changed = True
 
     def set(self, trait_change_notify=True, **traits):
@@ -98,7 +102,7 @@ class MlabSource(HasTraits):
         """
         try:
             self._disable_update = True
-            super(MlabSource, self).set(trait_change_notify, **traits)
+            super(MlabSource, self).trait_set(trait_change_notify, **traits)
         finally:
             self._disable_update = False
         if trait_change_notify:
@@ -150,7 +154,7 @@ class MGlyphSource(MlabSource):
 
         # First set the attributes without really doing anything since
         # the notification handlers are not called.
-        self.set(trait_change_notify=False, **traits)
+        self.trait_set(trait_change_notify=False, **traits)
 
         vectors = self.vectors
         scalars = self.scalars
@@ -164,12 +168,12 @@ class MGlyphSource(MlabSource):
             x = points[:, 0].ravel()
             y = points[:, 1].ravel()
             z = points[:, 2].ravel()
-            self.set(x=x, y=y, z=z, trait_change_notify=False)
+            self.trait_set(x=x, y=y, z=z, trait_change_notify=False)
 
         else:
             points = np.c_[x.ravel(), y.ravel(), z.ravel()].ravel()
             points.shape = (-1, 3)
-            self.set(points=points, trait_change_notify=False)
+            self.trait_set(points=points, trait_change_notify=False)
 
         u, v, w = self.u, self.v, self.w
         if u is not None:
@@ -180,20 +184,20 @@ class MGlyphSource(MlabSource):
                 vectors = np.c_[u.ravel(), v.ravel(),
                                 w.ravel()].ravel()
                 vectors.shape = (-1, 3)
-                self.set(vectors=vectors, trait_change_notify=False)
+                self.trait_set(vectors=vectors, trait_change_notify=False)
 
         if 'vectors' in traits:
             u = vectors[:, 0].ravel()
             v = vectors[:, 1].ravel()
             w = vectors[:, 2].ravel()
-            self.set(u=u, v=v, w=w, trait_change_notify=False)
+            self.trait_set(u=u, v=v, w=w, trait_change_notify=False)
 
         else:
             if u is not None and len(u) > 0:
                 vectors = np.c_[u.ravel(), v.ravel(),
                                 w.ravel()].ravel()
                 vectors.shape = (-1, 3)
-                self.set(vectors=vectors, trait_change_notify=False)
+                self.trait_set(vectors=vectors, trait_change_notify=False)
 
         if vectors is not None and len(vectors) > 0:
             assert len(points) == len(vectors)
@@ -205,13 +209,18 @@ class MGlyphSource(MlabSource):
         # Create the dataset.
         polys = np.arange(0, len(points), 1, 'l')
         polys = np.reshape(polys, (len(points), 1))
+        new_dataset = False
         if self.dataset is None:
             # Create new dataset if none exists
             pd = tvtk.PolyData()
+            new_dataset = True
         else:
             # Modify existing one.
             pd = self.dataset
-        pd.set(points=points, polys=polys)
+        # First set the polys to None to avoid accessing invalid points.
+        pd.polys = None
+        pd.trait_set(points=points)
+        pd.trait_set(verts=polys)
 
         if self.vectors is not None:
             pd.point_data.vectors = self.vectors
@@ -221,6 +230,8 @@ class MGlyphSource(MlabSource):
             pd.point_data.scalars.name = 'scalars'
 
         self.dataset = pd
+        if not new_dataset:
+            self.update()
 
     ######################################################################
     # Non-public interface.
@@ -299,9 +310,9 @@ class MVerticalGlyphSource(MGlyphSource):
     def _scalars_changed(self, s):
         self.dataset.point_data.scalars = s
         self.dataset.point_data.scalars.name = 'scalars'
-        self.set(vectors=np.c_[np.ones_like(s),
-                                  np.ones_like(s),
-                                  s])
+        self.trait_set(vectors=np.c_[np.ones_like(s),
+                               np.ones_like(s),
+                               s])
         self.update()
 
 
@@ -336,7 +347,7 @@ class MArraySource(MlabSource):
 
         # First set the attributes without really doing anything since
         # the notification handlers are not called.
-        self.set(trait_change_notify=False, **traits)
+        self.trait_set(trait_change_notify=False, **traits)
 
         vectors = self.vectors
         scalars = self.scalars
@@ -347,7 +358,7 @@ class MArraySource(MlabSource):
             u = vectors[:, 0].ravel()
             v = vectors[:, 1].ravel()
             w = vectors[:, 2].ravel()
-            self.set(u=u, v=v, w=w, trait_change_notify=False)
+            self.trait_set(u=u, v=v, w=w, trait_change_notify=False)
 
         else:
             if u is not None and len(u) > 0:
@@ -358,7 +369,7 @@ class MArraySource(MlabSource):
                 vectors = np.c_[u.ravel(), v.ravel(),
                                    w.ravel()].ravel()
                 vectors.shape = (u.shape[0], u.shape[1], w.shape[2], 3)
-                self.set(vectors=vectors, trait_change_notify=False)
+                self.trait_set(vectors=vectors, trait_change_notify=False)
 
         if vectors is not None and len(vectors) > 0 and scalars is not None:
             assert len(scalars) == len(vectors)
@@ -381,7 +392,7 @@ class MArraySource(MlabSource):
         else:
             ds = self.m_data
         old_scalar = ds.scalar_data
-        ds.set(vector_data=vectors,
+        ds.trait_set(vector_data=vectors,
                origin=[x.min(), y.min(), z.min()],
                spacing=[dx, dy, dz],
                scalar_data=scalars)
@@ -404,7 +415,7 @@ class MArraySource(MlabSource):
         ds.origin = [x.min(), y.min(), z.min()]
         ds.spacing = [dx, dy, dz]
         if self.m_data is not None:
-            self.m_data.set(origin=ds.origin, spacing=ds.spacing)
+            self.m_data.trait_set(origin=ds.origin, spacing=ds.spacing)
         self.update()
 
     def _u_changed(self, u):
@@ -455,7 +466,7 @@ class MLineSource(MlabSource):
 
         # First set the attributes without really doing anything since
         # the notification handlers are not called.
-        self.set(trait_change_notify=False, **traits)
+        self.trait_set(trait_change_notify=False, **traits)
 
         points = self.points
         scalars = self.scalars
@@ -465,28 +476,30 @@ class MLineSource(MlabSource):
             x = points[:, 0].ravel()
             y = points[:, 1].ravel()
             z = points[:, 2].ravel()
-            self.set(x=x, y=y, z=z, trait_change_notify=False)
+            self.trait_set(x=x, y=y, z=z, trait_change_notify=False)
 
         else:
             points = np.c_[x.ravel(), y.ravel(), z.ravel()].ravel()
             points.shape = (len(x), 3)
-            self.set(points=points, trait_change_notify=False)
+            self.trait_set(points=points, trait_change_notify=False)
 
         # Create the dataset.
         n_pts = len(points) - 1
         lines = np.zeros((n_pts, 2), 'l')
         lines[:, 0] = np.arange(0, n_pts - 0.5, 1, 'l')
         lines[:, 1] = np.arange(1, n_pts + 0.5, 1, 'l')
+        new_dataset = False
         if self.dataset is None:
             pd = tvtk.PolyData()
+            new_dataset = True
         else:
             pd = self.dataset
         # Avoid lines refering to non existing points: First set the
         # lines to None, then set the points, then set the lines
         # refering to the new points.
-        pd.set(lines=None)
-        pd.set(points=points)
-        pd.set(lines=lines)
+        pd.trait_set(lines=None)
+        pd.trait_set(points=points)
+        pd.trait_set(lines=lines)
 
         if scalars is not None and len(scalars) > 0:
             assert len(x) == len(scalars)
@@ -494,6 +507,8 @@ class MLineSource(MlabSource):
             pd.point_data.scalars.name = 'scalars'
 
         self.dataset = pd
+        if not new_dataset:
+            self.update()
 
     ######################################################################
     # Non-public interface.
@@ -549,7 +564,7 @@ class MArray2DSource(MlabSource):
 
         # First set the attributes without really doing anything since
         # the notification handlers are not called.
-        self.set(trait_change_notify=False, **traits)
+        self.trait_set(trait_change_notify=False, **traits)
         x, y, mask = self.x, self.y, self.mask
         scalars = self.scalars
 
@@ -565,11 +580,11 @@ class MArray2DSource(MlabSource):
             scalars[mask.astype('bool')] = np.nan
             # The NaN trick only works with floats.
             scalars = scalars.astype('float')
-            self.set(scalars=scalars, trait_change_notify=False)
+            self.trait_set(scalars=scalars, trait_change_notify=False)
 
         z = np.array([0])
 
-        self.set(x=x, y=y, z=z, trait_change_notify=False)
+        self.trait_set(x=x, y=y, z=z, trait_change_notify=False)
         # Do some magic to extract the first row/column, independently of
         # the shape of x and y
 
@@ -589,13 +604,13 @@ class MArray2DSource(MlabSource):
         else:
             ds = self.m_data
         old_scalar = ds.scalar_data
-        ds.set(origin=[x.min(), y.min(), 0],
-               spacing=[dx, dy, 1],
-               scalar_data=scalars)
+        ds.trait_set(origin=[x.min(), y.min(), 0],
+                     spacing=[dx, dy, 1],
+                     scalar_data=scalars)
         if old_scalar is scalars:
             ds._scalar_data_changed(scalars)
 
-        self.dataset = ds.outputs[0]
+        self.dataset = ds.get_output_dataset()
         self.m_data = ds
 
     #####################################################################
@@ -619,7 +634,7 @@ class MArray2DSource(MlabSource):
         ds.origin = [x.min(), y.min(), 0]
         ds.spacing = [dx, dy, 1]
         if self.m_data is not None:
-            self.m_data.set(origin=ds.origin, spacing=ds.spacing)
+            self.m_data.trait_set(origin=ds.origin, spacing=ds.spacing)
         self.update()
 
     def _scalars_changed(self, s):
@@ -628,7 +643,7 @@ class MArray2DSource(MlabSource):
             s[mask.astype('bool')] = np.nan
             # The NaN tric only works with floats.
             s = s.astype('float')
-            self.set(scalars=s, trait_change_notify=False)
+            self.trait_set(scalars=s, trait_change_notify=False)
         old = self.m_data.scalar_data
         self.m_data.scalar_data = s
         if s is old:
@@ -664,7 +679,7 @@ class MGridSource(MlabSource):
 
         # First set the attributes without really doing anything since
         # the notification handlers are not called.
-        self.set(trait_change_notify=False, **traits)
+        self.trait_set(trait_change_notify=False, **traits)
 
         points = self.points
         scalars = self.scalars
@@ -674,7 +689,7 @@ class MGridSource(MlabSource):
             scalars[mask.astype('bool')] = np.nan
             # The NaN trick only works with floats.
             scalars = scalars.astype('float')
-            self.set(scalars=scalars, trait_change_notify=False)
+            self.trait_set(scalars=scalars, trait_change_notify=False)
 
         assert len(x.shape) == 2, "Array x must be 2 dimensional."
         assert len(y.shape) == 2, "Array y must be 2 dimensional."
@@ -689,7 +704,7 @@ class MGridSource(MlabSource):
         nx, ny = x.shape
         points = np.c_[x.ravel(), y.ravel(), z.ravel()].ravel()
         points.shape = (nx * ny, 3)
-        self.set(points=points, trait_change_notify=False)
+        self.trait_set(points=points, trait_change_notify=False)
 
         i, j = np.mgrid[0:nx - 1, 0:ny - 1]
         i, j = np.ravel(i), np.ravel(j)
@@ -700,21 +715,27 @@ class MGridSource(MlabSource):
         triangles[0:nt, 0], triangles[0:nt, 1], triangles[0:nt, 2] = t1
         triangles[nt:, 0], triangles[nt:, 1], triangles[nt:, 2] = t2
 
+        new_dataset = False
         if self.dataset is None:
             pd = tvtk.PolyData()
+            new_dataset = True
         else:
             pd = self.dataset
-        pd.set(points=points, polys=triangles)
+        pd.trait_set(polys=None)
+        pd.trait_set(points=points)
+        pd.trait_set(polys=triangles)
 
         if scalars is not None and len(scalars) > 0:
             if not scalars.flags.contiguous:
                 scalars = scalars.copy()
-                self.set(scalars=scalars, trait_change_notify=False)
+                self.trait_set(scalars=scalars, trait_change_notify=False)
             assert x.shape == scalars.shape
             pd.point_data.scalars = scalars.ravel()
             pd.point_data.scalars.name = 'scalars'
 
         self.dataset = pd
+        if not new_dataset:
+            self.update()
 
     ######################################################################
     # Non-public interface.
@@ -744,7 +765,7 @@ class MGridSource(MlabSource):
             s[mask.astype('bool')] = np.nan
             # The NaN tric only works with floats.
             s = s.astype('float')
-            self.set(scalars=s, trait_change_notify=False)
+            self.trait_set(scalars=s, trait_change_notify=False)
 
         self.dataset.point_data.scalars = s.ravel()
         self.dataset.point_data.scalars.name = 'scalars'
@@ -778,7 +799,7 @@ class MTriangularMeshSource(MlabSource):
 
         # First set the attributes without really doing anything since
         # the notification handlers are not called.
-        self.set(trait_change_notify=False, **traits)
+        self.trait_set(trait_change_notify=False, **traits)
 
         points = self.points
         scalars = self.scalars
@@ -786,7 +807,7 @@ class MTriangularMeshSource(MlabSource):
         x, y, z = self.x, self.y, self.z
         points = np.c_[x.ravel(), y.ravel(), z.ravel()].ravel()
         points.shape = (-1, 3)
-        self.set(points=points, trait_change_notify=False)
+        self.trait_set(points=points, trait_change_notify=False)
 
         triangles = self.triangles
         assert triangles.shape[1] == 3, \
@@ -796,18 +817,23 @@ class MTriangularMeshSource(MlabSource):
         assert triangles.min() >= 0, \
             "The triangles indices must be positive or null"
 
+        new_dataset = False
         if self.dataset is None:
             pd = tvtk.PolyData()
+            new_dataset = True
         else:
             pd = self.dataset
         # Set the points first, and the triangles after: so that the
         # polygone can refer to the right points, in the polydata.
-        pd.set(points=points)
-        pd.set(polys=triangles)
 
-        if (not 'scalars' in traits
-                    and scalars is not None
-                    and scalars.shape != x.shape):
+        # Set the polys to None so that when the points are set, the
+        # cells do not point to garbage.
+        pd.polys = None
+        pd.trait_set(points=points)
+        pd.trait_set(polys=triangles)
+
+        if ('scalars' not in traits and scalars is not None
+           and scalars.shape != x.shape):
             # The scalars where set probably automatically to z, by the
             # factory. We need to reset them, as the size has changed.
             scalars = z
@@ -815,12 +841,14 @@ class MTriangularMeshSource(MlabSource):
         if scalars is not None and len(scalars) > 0:
             if not scalars.flags.contiguous:
                 scalars = scalars.copy()
-                self.set(scalars=scalars, trait_change_notify=False)
+                self.trait_set(scalars=scalars, trait_change_notify=False)
             assert x.shape == scalars.shape
             pd.point_data.scalars = scalars.ravel()
             pd.point_data.scalars.name = 'scalars'
 
         self.dataset = pd
+        if not new_dataset:
+            self.update()
 
     ######################################################################
     # Non-public interface.
@@ -1192,7 +1220,7 @@ def array2d_source(*args, **kwargs):
 
     If 3 positional arguments are passed the last one must be an array s,
     or a callable, f, that returns an array. x and y give the
-    coordinnates of positions corresponding to the s values.
+    coordinates of positions corresponding to the s values.
 
     x and y can be 1D or 2D arrays (such as returned by numpy.ogrid or
     numpy.mgrid), but the points should be located on an orthogonal grid
