@@ -1,10 +1,9 @@
 # Wrapped in a try/except in those situations where someone hasn't installed
 # as an egg.  What do we do then?  For now, we just punt since we don't want
 # to define the version number in two places.
+import importlib.metadata
+
 try:
-    import pkg_resources
-    version = pkg_resources.require('Mayavi')[0].version
-except:
+    version = importlib.metadata.version("mayavi")
+except Exception:
     version = ''
-
-
