@@ -28,10 +28,10 @@ from traits.api import HasTraits, Range, false, \
                                  Instance, Trait, List
 from traitsui.api import View, Group, Handler, ListEditor, Item
 from tvtk.api import tvtk
-from tvtk.tvtk_base import vtk_color_trait, TraitRevPrefixMap
+from tvtk.tvtk_base import vtk_color_trait, RevPrefixMap
+from tvtk.common import configure_input, configure_input_data
 from apptools.persistence import state_pickler
 
-
 ######################################################################
 # `LightGlyph` class.
 ######################################################################
@@ -56,10 +56,10 @@ class LightGlyph(HasTraits):
         tf.transform = t
         t.rotate_y(90.0)
         t.translate((-2, 0, 0))
-        tf.input = arrow.output
+        configure_input_data(tf, arrow.output)
 
         mapper = tvtk.PolyDataMapper()
-        mapper.input = tf.output
+        configure_input(mapper, tf)
 
         self.actor = actor = tvtk.Follower()
         actor.mapper = mapper
@@ -229,7 +229,7 @@ class CameraLight(HasTraits):
         self.source.intensity = val
 
     def _color_changed(self, val):
-        self.source.color = val
+        self.source.set_color(val)
         self.glyph.set_color(val)
 
     def _elevation_changed(self, val):
@@ -306,9 +306,10 @@ class LightManager(HasTraits):
     # default mode used to initialize the lights to a sane default.
     # The user can always change the light configuration via the GUI
     # such that the mode is neither 'vtk' nor 'raymond'.
-    light_mode = Trait('raymond', TraitRevPrefixMap({'raymond':1,
-                                                     'vtk':2}),
-                       desc='specifies a default lighting mode')
+    light_mode = RevPrefixMap({'raymond': 1,
+                               'vtk': 2},
+                              default_value='raymond',
+                              desc='specifies a default lighting mode')
 
     # Specify the number of lights.  If new lights are added they are
     # by default turned off.  Similarly if the number of lights are
@@ -467,4 +468,3 @@ class LightManager(HasTraits):
                 light = self.lights.pop()
                 light.close(self.renwin)
             changed = True
-
