@@ -7,12 +7,9 @@ functionality. See the class docs for more details.
 
 """
 # Author: Prabhu Ramachandran <prabhu@enthought.com>
-# Copyright (c) 2007-2016, Enthought, Inc.
+# Copyright (c) 2007-2020, Enthought, Inc.
 # License: BSD Style.
 
-
-from __future__ import print_function
-
 import os
 import os.path
 
@@ -28,8 +25,11 @@ from traits.api import HasPrivateTraits, HasTraits, Any, Int, \
 from tvtk.pyface import light_manager
 
 
-VTK_VER = tvtk.Version().vtk_version
-
+def set_magnification(w2if, magnification):
+    if hasattr(w2if, 'magnification'):
+        w2if.magnification = magnification
+    else:
+        w2if.scale = magnification, magnification
 
 
 ######################################################################
@@ -125,7 +125,10 @@ class TVTKScene(HasPrivateTraits):
     # `self.render_window.aa_frames` in order to produce anti-aliased
     # figures when a scene is saved to an image.  It then restores the
     # `aa_frames` in order to get interactive rendering rates.
-    anti_aliasing_frames = Range(0, 20, 8, desc='number of frames to use for anti-aliasing when saving a scene')
+    anti_aliasing_frames = Range(
+        0, 20, 8,
+        desc='number of frames to use for anti-aliasing when saving a scene'
+    )
 
     # Default JPEG quality.
     jpeg_quality = Range(10, 100, 95, desc='the quality of the JPEG image to produce')
@@ -187,6 +190,11 @@ class TVTKScene(HasPrivateTraits):
     _camera_observer_id = Int(transient=True)
     _script_id = Str(transient=True)
 
+    # Saved light_manager settings while loading a scene.  The light manager
+    # may not be created at the time a scene is loaded from disk, so if it
+    # is saved here, when it is created the state is set.
+    _saved_light_manager_state = Any(transient=True)
+
     # The renderer instance.
     _renderer = Instance(tvtk.Renderer)
     _renwin = Instance(tvtk.RenderWindow)
@@ -205,7 +213,6 @@ class TVTKScene(HasPrivateTraits):
 
         # Used to set the view of the scene.
         self._def_pos = 1
-
         self.control = self._create_control(parent)
         self._renwin.update_traits()
 
@@ -217,6 +224,7 @@ class TVTKScene(HasPrivateTraits):
         for x in ['control', '_renwin', '_interactor', '_camera',
                   '_busy_count', '__sync_trait__', 'recorder',
                   '_last_camera_state', '_camera_observer_id',
+                  '_saved_light_manager_state',
                   '_script_id', '__traits_listener__']:
             d.pop(x, None)
         # Additionally pickle these.
@@ -407,7 +415,7 @@ class TVTKScene(HasPrivateTraits):
             raise ValueError(
                 'Unable to find suitable image type for given file extension.'
             )
-        meth = getattr(self, 'save_' + meth_map[ext])
+        meth = getattr(self, 'save_' + meth_map[ext.lower()])
         if size is not None:
             orig_size = self.get_size()
             self.set_size(size)
@@ -422,11 +430,7 @@ class TVTKScene(HasPrivateTraits):
         """Saves the rendered scene to a rasterized PostScript image.
         For vector graphics use the save_gl2ps method."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=
-                                              not self.off_screen_rendering)
-            w2if.magnification = self.magnification
-            self._lift()
-            w2if.input = self._renwin
+            w2if = self._get_window_to_image()
             ex = tvtk.PostScriptWriter()
             ex.file_name = file_name
             configure_input(ex, w2if)
@@ -435,11 +439,7 @@ class TVTKScene(HasPrivateTraits):
     def save_bmp(self, file_name):
         """Save to a BMP image file."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=
-                                              not self.off_screen_rendering)
-            w2if.magnification = self.magnification
-            self._lift()
-            w2if.input = self._renwin
+            w2if = self._get_window_to_image()
             ex = tvtk.BMPWriter()
             ex.file_name = file_name
             configure_input(ex, w2if)
@@ -448,11 +448,7 @@ class TVTKScene(HasPrivateTraits):
     def save_tiff(self, file_name):
         """Save to a TIFF image file."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=
-                                              not self.off_screen_rendering)
-            w2if.magnification = self.magnification
-            self._lift()
-            w2if.input = self._renwin
+            w2if = self._get_window_to_image()
             ex = tvtk.TIFFWriter()
             ex.file_name = file_name
             configure_input(ex, w2if)
@@ -461,11 +457,7 @@ class TVTKScene(HasPrivateTraits):
     def save_png(self, file_name):
         """Save to a PNG image file."""
         if len(file_name) != 0:
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=
-                                              not self.off_screen_rendering)
-            w2if.magnification = self.magnification
-            self._lift()
-            w2if.input = self._renwin
+            w2if = self._get_window_to_image()
             ex = tvtk.PNGWriter()
             ex.file_name = file_name
             configure_input(ex, w2if)
@@ -478,11 +470,7 @@ class TVTKScene(HasPrivateTraits):
         if len(file_name) != 0:
             if not quality and not progressive:
                 quality, progressive = self.jpeg_quality, self.jpeg_progressive
-            w2if = tvtk.WindowToImageFilter(read_front_buffer=
-                                              not self.off_screen_rendering)
-            w2if.magnification = self.magnification
-            self._lift()
-            w2if.input = self._renwin
+            w2if = self._get_window_to_image()
             ex = tvtk.JPEGWriter()
             ex.quality = quality
             ex.progressive = progressive
@@ -558,62 +546,12 @@ class TVTKScene(HasPrivateTraits):
         ex.render_window = self._renwin
         ex.background = bg
 
-        if VTK_VER[:3] in ['4.2', '4.4']:
-            # The vtkRIBExporter is broken in respect to VTK light
-            # types.  Therefore we need to convert all lights into
-            # scene lights before the save and later convert them
-            # back.
-
-            ########################################
-            # Internal functions
-            def x3to4(x):
-                # convert 3-vector to 4-vector (w=1 -> point in space)
-                return (x[0], x[1], x[2], 1.0 )
-            def x4to3(x):
-                # convert 4-vector to 3-vector
-                return (x[0], x[1], x[2])
-
-            def cameralight_transform(light, xform, light_type):
-                # transform light by 4x4 matrix xform
-                origin = x3to4(light.position)
-                focus = x3to4(light.focal_point)
-                neworigin = xform.multiply_point(origin)
-                newfocus = xform.multiply_point(focus)
-                light.position = x4to3(neworigin)
-                light.focal_point = x4to3(newfocus)
-                light.light_type = light_type
-            ########################################
-
-            save_lights_type=[]
-            for light in self.light_manager.lights:
-                save_lights_type.append(light.source.light_type)
-
-            # Convert lights to scene lights.
-            cam = self.camera
-            xform = tvtk.Matrix4x4()
-            xform.deep_copy(cam.camera_light_transform_matrix)
-            for light in self.light_manager.lights:
-                cameralight_transform(light.source, xform, "scene_light")
-
-            # Write the RIB file.
-            self._exporter_write(ex)
-
-            # Now re-convert lights to camera lights.
-            xform.invert()
-            for i,light in enumerate(self.light_manager.lights):
-                cameralight_transform(light.source, xform, save_lights_type[i])
-
-            # Change the camera position. Otherwise VTK would render
-            # one broken frame after the export.
-            cam.roll(0.5)
-            cam.roll(-0.5)
-        else:
-            self._exporter_write(ex)
+        self._exporter_write(ex)
 
     def save_wavefront(self, file_name):
         """Save scene to a Wavefront OBJ file.  Two files are
         generated.  One with a .obj extension and another with a .mtl
-        extension which contains the material proerties.
+        extension which contains the material properties.
 
         Keyword Arguments:
 
@@ -711,7 +649,7 @@ class TVTKScene(HasPrivateTraits):
             ex.write()
 
     def save_povray(self, file_name):
-        """Save scene to a POVRAY (Persistance of Vision Raytracer),
+        """Save scene to a POVRAY (Persistence of Vision Raytracer),
         file (http://www.povray.org).
 
         Keyword Arguments:
@@ -752,6 +690,12 @@ class TVTKScene(HasPrivateTraits):
         """Returns the vtkRenderWindowInteractor of the parent class"""
         return self._interactor
 
+    def _set_interactor(self, iren):
+        if self._interactor is not None:
+            self._interactor.render_window = None
+        self._interactor = iren
+        iren.render_window = self._renwin
+
     def _get_render_window(self):
         """Returns the scene's render window."""
         return self._renwin
@@ -796,20 +740,33 @@ class TVTKScene(HasPrivateTraits):
     def _create_control(self, parent):
         """ Create the toolkit-specific control that represents the widget. """
 
-        # Create the renderwindow.
-        renwin = self._renwin = tvtk.RenderWindow()
-        # If we are doing offscreen rendering we set the window size to
-        # (1,1) so the window does not appear at all
         if self.off_screen_rendering:
-            renwin.size = (1,1)
+            if hasattr(tvtk, 'EGLRenderWindow'):
+                renwin = tvtk.EGLRenderWindow()
+            elif hasattr(tvtk, 'OSOpenGLRenderWindow'):
+                renwin = tvtk.OSOpenGLRenderWindow()
+            else:
+                renwin = tvtk.RenderWindow()
+                # If we are doing offscreen rendering we set the window size to
+                # (1,1) so the window does not appear at all
+                renwin.size = (1, 1)
 
-        renwin.set(point_smoothing=self.point_smoothing,
-                   line_smoothing=self.line_smoothing,
-                   polygon_smoothing=self.polygon_smoothing)
+            self._renwin = renwin
+            self._interactor = tvtk.GenericRenderWindowInteractor(
+                render_window=renwin
+            )
+        else:
+            renwin = self._renwin = tvtk.RenderWindow()
+            self._interactor = tvtk.RenderWindowInteractor(
+                render_window=renwin
+            )
+
+        renwin.trait_set(point_smoothing=self.point_smoothing,
+                         line_smoothing=self.line_smoothing,
+                         polygon_smoothing=self.polygon_smoothing)
         # Create a renderer and add it to the renderwindow
         self._renderer = tvtk.Renderer()
         renwin.add_renderer(self._renderer)
-        self._interactor = tvtk.RenderWindowInteractor(render_window=renwin)
         # Save a reference to our camera so it is not GC'd -- needed for
         # the sync_traits to work.
         self._camera = self.camera
@@ -830,7 +787,6 @@ class TVTKScene(HasPrivateTraits):
         self._interactor.initialize()
         self._interactor.render()
         self.light_manager = light_manager.LightManager(self)
-
         if self.off_screen_rendering:
             # We want the default size to be the normal (300, 300).
             # Setting the size now should not resize the window if
@@ -839,6 +795,15 @@ class TVTKScene(HasPrivateTraits):
 
         return self._interactor
 
+    def _get_window_to_image(self):
+        w2if = tvtk.WindowToImageFilter(
+            read_front_buffer=not self.off_screen_rendering
+        )
+        set_magnification(w2if, self.magnification)
+        self._lift()
+        w2if.input = self._renwin
+        return w2if
+
     def _lift(self):
         """Lift the window to the top. Useful when saving screen to an
         image."""
@@ -849,13 +814,20 @@ class TVTKScene(HasPrivateTraits):
         # Bumps up the anti-aliasing frames when the image is saved so
         # that the saved picture looks nicer.
         rw = self.render_window
-        aa_frames = rw.aa_frames
-        rw.aa_frames = self.anti_aliasing_frames
+        if hasattr(rw, 'aa_frames'):
+            aa_frames = rw.aa_frames
+            rw.aa_frames = self.anti_aliasing_frames
+        else:
+            aa_frames = rw.multi_samples
+            rw.multi_samples = self.anti_aliasing_frames
         rw.render()
         ex.update()
         ex.write()
         # Set the frames back to original setting.
-        rw.aa_frames = aa_frames
+        if hasattr(rw, 'aa_frames'):
+            rw.aa_frames = aa_frames
+        else:
+            rw.multi_samples = aa_frames
         rw.render()
 
     def _update_view(self, x, y, z, vx, vy, vz):
@@ -927,6 +899,12 @@ class TVTKScene(HasPrivateTraits):
             messenger.disconnect(i_vtk, 'EndInteractionEvent',
                                  self._record_camera_position)
 
+    def _light_manager_changed(self, lm):
+        if lm is not None:
+            if self._saved_light_manager_state is not None:
+                lm.__set_pure_state__(self._saved_light_manager_state)
+                self._saved_light_manager_state = None
+
     def _movie_maker_default(self):
         from tvtk.pyface.movie_maker import MovieMaker
         return MovieMaker(scene=self)
