@@ -12,9 +12,13 @@ from pyface.qt import QtGui
 
 # Enthought library imports.
 from traits.api import Any, Bool, Callable, Dict, Str
-from traitsui.qt4.editor import Editor
+try:
+    from traitsui.qt4.editor import Editor
+except ModuleNotFoundError:
+    from traitsui.qt.editor import Editor
 from traitsui.basic_editor_factory import BasicEditorFactory
-from decorated_scene import DecoratedScene
+
+from .decorated_scene import DecoratedScene
 
 #####################################################################
 # `_ActorEditor` class
