@@ -27,7 +27,7 @@ import wx
 from pyface.api import ImageResource
 from pyface.action.api import ToolBarManager, Group, Action
 from tvtk.api import tvtk
-from traits.api import Instance, false, List, Either
+from traits.api import Bool, Instance, List, Either, TraitError
 
 # Local imports.
 from .scene import Scene, popup_save
@@ -57,7 +57,7 @@ class DecoratedScene(Scene):
         axes = None
 
     # Determine if the orientation axis is shown or not.
-    show_axes = false
+    show_axes = Bool(False)
 
     # The list of actions represented in the toolbar
     actions = List(Either(Action, Group))
@@ -114,7 +114,7 @@ class DecoratedScene(Scene):
             # For VTK versions < 5.0.
             return
 
-        axes.set(
+        axes.trait_set(
             normalized_tip_length=(0.4, 0.4, 0.4),
             normalized_shaft_length=(0.6, 0.6, 0.6),
             shaft_type='cylinder'
@@ -123,10 +123,10 @@ class DecoratedScene(Scene):
         p = axes.x_axis_caption_actor2d.caption_text_property
         axes.y_axis_caption_actor2d.caption_text_property = p
         axes.z_axis_caption_actor2d.caption_text_property = p
-        p.set(color=(1,1,1), shadow=False, italic=False)
+        p.trait_set(color=(1,1,1), shadow=False, italic=False)
         self._background_changed(self.background)
 
-        self.marker.set(key_press_activation=False)
+        self.marker.trait_set(key_press_activation=False)
         self.marker.orientation_marker = axes
 
     def _get_tool_bar_manager(self):
@@ -197,11 +197,13 @@ class DecoratedScene(Scene):
             m = self.marker
             s = value[0] + value[1] + value[2]
             if s <= 1.0:
-                p.color = (1,1,1)
-                m.set_outline_color(1,1,1)
+                p.color = (1, 1, 1)
             else:
-                p.color = (0,0,0)
-                m.set_outline_color(0,0,0)
+                p.color = (0, 0, 0)
+            try:
+                m.outline_color = p.color  #VTK 9+
+            except TraitError:
+                m.set_outline_color(*p.color)
             self.render()
 
 
