@@ -1,5 +1,5 @@
 #------------------------------------------------------------------------------
-# Copyright (c) 2005-2016, Enthought, Inc.
+# Copyright (c) 2005-2020, Enthought, Inc.
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -16,7 +16,7 @@ the class docs for more details.
 
 """
 # Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2004-2016, Enthought, Inc.
+# Copyright (c) 2004-2020, Enthought, Inc.
 # License: BSD Style.
 
 
@@ -81,7 +81,7 @@ class FullScreen(object):
 
         # Gets parameters for stereo visualization
         if self.old_rw.stereo_render:
-            full_rw.set(stereo_type=self.old_rw.stereo_type, stereo_render=True)
+            full_rw.trait_set(stereo_type=self.old_rw.stereo_type, stereo_render=True)
 
         # Starts the interactor
         self.iren.initialize()
@@ -256,6 +256,9 @@ class Scene(TVTKScene, Widget):
                                        show_label=False),
                                   ),
                             label='Scene'),
+                         Group( Item(name='picker',
+                                style='custom', show_label=False),
+                                label='Picker'),
                          Group( Item(name='light_manager',
                                 style='custom', show_label=False),
                                 label='Lights'),
@@ -363,6 +366,7 @@ class Scene(TVTKScene, Widget):
                 return
             if key.lower() in ['q', 'e'] or keycode == wx.WXK_ESCAPE:
                 self._disable_fullscreen()
+                self.picker.close_picker()
             if key.lower() in ['w']:
                 event.Skip()
                 return
@@ -496,7 +500,6 @@ class Scene(TVTKScene, Widget):
         self._vtk_control.OnKeyUp(event)
         event.Skip()
 
-
     def OnPaint(self, event):
         """This method is overridden temporarily in order to create
         the light manager.  This is necessary because it makes sense
@@ -507,6 +510,9 @@ class Scene(TVTKScene, Widget):
         and the default paint handler of the
         wxVTKRenderWindowInteractor is used instead."""
 
+        if self._vtk_control is None:
+            return
+
         # Call the original handler (this will Show the widget)
         self._vtk_control.OnPaint(event)
         if len(self.renderer.lights) == 0:
@@ -527,8 +533,8 @@ class Scene(TVTKScene, Widget):
         messenger.connect(vtk_rw, 'EndEvent', self._end_event_callback)
 
         # Reset the event handler to the default since our job is done.
-        wx.EVT_PAINT(self._vtk_control, None) # Remove the default handler.
-        wx.EVT_PAINT(self._vtk_control, self._vtk_control.OnPaint)
+        self._vtk_control.Bind(wx.EVT_PAINT, None) # Remove the default handler.
+        self._vtk_control.Bind(wx.EVT_PAINT, self._vtk_control.OnPaint)
 
     def OnSize(self, event):
         """Overrides the default OnSize in order to refresh the traits
@@ -567,24 +573,24 @@ class Scene(TVTKScene, Widget):
                                                                  stereo=self.stereo)
 
         # Override these handlers.
-        wx.EVT_CHAR(window, None) # Remove the default handler.
-        wx.EVT_CHAR(window, self.OnKeyDown)
-        wx.EVT_KEY_UP(window, None) # Remove the default handler.
-        wx.EVT_KEY_UP(window, self.OnKeyUp)
-        wx.EVT_PAINT(window, None) # Remove the default handler.
-        wx.EVT_PAINT(window, self.OnPaint)
-        wx.EVT_SIZE(window, None) # Remove the default handler.
-        wx.EVT_SIZE(window, self.OnSize)
+        window.Bind(wx.EVT_CHAR, None) # Remove the default handler.
+        window.Bind(wx.EVT_CHAR, self.OnKeyDown)
+        window.Bind(wx.EVT_KEY_UP, None) # Remove the default handler.
+        window.Bind(wx.EVT_KEY_UP, self.OnKeyUp)
+        window.Bind(wx.EVT_PAINT, None) # Remove the default handler.
+        window.Bind(wx.EVT_PAINT, self.OnPaint)
+        window.Bind(wx.EVT_SIZE, None) # Remove the default handler.
+        window.Bind(wx.EVT_SIZE, self.OnSize)
         # Override the button down and up handlers as well to note the
         # interaction.  This is to toggle the busy status nicely.
         for evt in (wx.EVT_LEFT_DOWN, wx.EVT_RIGHT_DOWN,
                     wx.EVT_MIDDLE_DOWN):
-            evt(window, None)
-            evt(window, self.OnButtonDown)
+            window.Bind(evt, None)
+            window.Bind(evt, self.OnButtonDown)
         for evt in (wx.EVT_LEFT_UP, wx.EVT_RIGHT_UP,
                     wx.EVT_MIDDLE_UP):
-            evt(window, None)
-            evt(window, self.OnButtonUp)
+            window.Bind(evt, None)
+            window.Bind(evt, self.OnButtonUp)
 
         # Enable the widget.
         window.Enable(1)
@@ -593,7 +599,7 @@ class Scene(TVTKScene, Widget):
 
         # Grab the renderwindow.
         renwin = self._renwin = tvtk.to_tvtk(window.GetRenderWindow())
-        renwin.set(point_smoothing=self.point_smoothing,
+        renwin.trait_set(point_smoothing=self.point_smoothing,
                    line_smoothing=self.line_smoothing,
                    polygon_smoothing=self.polygon_smoothing)
         # Create a renderer and add it to the renderwindow
@@ -652,11 +658,11 @@ class Scene(TVTKScene, Widget):
             w.SetSize(sz)
             window._idle_count -= 1
             if window._idle_count < 1:
-                wx.EVT_IDLE(window, None)
+                window.Bind(wx.EVT_IDLE, None)
                 del window._idle_count
 
         window._idle_count = 2
-        wx.EVT_IDLE(window, _do_idle)
+        window.Bind(wx.EVT_IDLE, _do_idle)
 
         self._interactor = tvtk.to_tvtk(window._Iren)
         return window
@@ -697,27 +703,9 @@ class Scene(TVTKScene, Widget):
             fs.close()
             self._fullscreen = None
         elif fs is None:
-            ver = tvtk.Version()
-            popup = False
-            if wx.Platform == '__WXMSW__':
-                popup = True
-            elif ver.vtk_major_version > 5:
-                popup = True
-            elif (ver.vtk_major_version == 5) and \
-                 ((ver.vtk_minor_version >= 1) or \
-                  (ver.vtk_build_version > 2)):
-                popup = True
-            if popup:
-                # There is a bug with earlier versions of VTK that
-                # breaks reparenting a window which is why we test for
-                # the version above.
-                f = PopupScene(self)
-                self._fullscreen = f
-                f.fullscreen()
-            else:
-                f = FullScreen(self)
-                f.run() # This will block.
-                self._fullscreen = None
+            f = PopupScene(self)
+            self._fullscreen = f
+            f.fullscreen()
 
     def _disable_fullscreen(self):
         fs = self._fullscreen
