@@ -7,7 +7,7 @@ Based on a Tk version of this widget by Gerald Knizia <cgk.d@gmx.net>
 Ported to wxPython by Pete Schmitt <schmitt@colorado.edu>
 Cleaned up and enhanced for use with MayaVi2 by Prabhu Ramachandran
 
-Copyright (c) 2005-2015, Gerald Knizia, Pete Schmitt and Prabhu Ramachandran
+Copyright (c) 2005-2020, Gerald Knizia, Pete Schmitt and Prabhu Ramachandran
 """
 
 
@@ -15,8 +15,9 @@ Copyright (c) 2005-2015, Gerald Knizia, Pete Schmitt and Prabhu Ramachandran
 import wx
 
 # Local imports
-from .gradient_editor import (ColorControlPoint, ChannelBase, FunctionControl,
-    GradientEditorWidget)
+from tvtk.util.gradient_editor import (
+    ColorControlPoint, ChannelBase, FunctionControl, GradientEditorWidget
+)
 
 ##########################################################################
 # `wxGradientControl` class.
@@ -392,7 +393,7 @@ class wxGradientEditorWidget(wx.Panel, GradientEditorWidget):
         (lookuptable) ``*.grad`` (gradient table for use with this program),
         and ``*.jpg`` (image of the gradient)
         """
-        dlg = wx.FileDialog(self, "Save LUT to...", style=wx.SAVE)
+        dlg = wx.FileDialog(self, "Save LUT to...", style=wx.FD_SAVE)
         wildcard = "Gradient Files (.grad)|*.grad|"   \
                    "All files (*.*)|*.*"
         dlg.SetWildcard(wildcard)
@@ -405,7 +406,7 @@ class wxGradientEditorWidget(wx.Panel, GradientEditorWidget):
         """
         Load a ``*.grad`` lookuptable file using wxpython dialog
         """
-        style = wx.OPEN | wx.HIDE_READONLY
+        style = wx.FD_OPEN
         dlg = wx.FileDialog(self, "Open a file", style=style)
         wildcard = "Gradient Files (.grad)|*.grad|"   \
                    "All files (*.*)|*.*"
@@ -503,14 +504,14 @@ class wxGradientEditor(wx.Frame):
 # Test application.
 ##########################################################################
 def main():
-    from .traitsui_gradient_editor import make_test_table
+    from tvtk.util.traitsui_gradient_editor import make_test_table
     table, ctf, otf = make_test_table(lut=False)
     # the actual gradient editor code.
     def on_color_table_changed():
         """If we had a vtk window running, update it here"""
         print("Update Render Window")
 
-    app = wx.PySimpleApp()
+    app = wx.App(False)
     editor = wxGradientEditor(table,
                               on_color_table_changed,
                               colors=['rgb', 'a', 'h', 's', 'v'],
